ApAdc class

Raw ADC output.

AP_ADC

Implemented types

Constructors

ApAdc({required uint16_t adc1, required uint16_t adc2, required uint16_t adc3, required uint16_t adc4, required uint16_t adc5, required uint16_t adc6})
ApAdc.parse(ByteData data_)
factory

Properties

adc1 AccelcalVehiclePos
ADC output 1.
final
adc2 AccelcalVehiclePos
ADC output 2.
final
adc3 AccelcalVehiclePos
ADC output 3.
final
adc4 AccelcalVehiclePos
ADC output 4.
final
adc5 AccelcalVehiclePos
ADC output 5.
final
adc6 AccelcalVehiclePos
ADC output 6.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited