CameraFeedback class

Camera Capture Feedback.

CAMERA_FEEDBACK

Implemented types

Constructors

CameraFeedback({required uint64_t timeUsec, required int32_t lat, required int32_t lng, required float altMsl, required float altRel, required float roll, required float pitch, required float yaw, required float focLen, required uint16_t imgIdx, required uint8_t targetSystem, required uint8_t camIdx, required CameraFeedbackFlags flags, required uint16_t completedCaptures})
CameraFeedback.parse(ByteData data_)
factory

Properties

altMsl float
Altitude (MSL).
final
altRel float
Altitude (Relative to HOME location).
final
camIdx AccelcalVehiclePos
Camera ID.
final
completedCaptures AccelcalVehiclePos
Completed image captures.
final
flags AccelcalVehiclePos
Feedback flags.
final
focLen float
Focal Length.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
imgIdx AccelcalVehiclePos
Image index.
final
lat AccelcalVehiclePos
Latitude.
final
lng AccelcalVehiclePos
Longitude.
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
pitch float
Camera Pitch angle (earth frame, +-180).
final
roll float
Camera Roll angle (earth frame, +-180).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSystem AccelcalVehiclePos
System ID.
final
timeUsec AccelcalVehiclePos
Image timestamp (since UNIX epoch), as passed in by CAMERA_STATUS message (or autopilot if no CCB).
final
yaw float
Camera Yaw (earth frame, 0-360, true).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited