CameraSettings class

Settings of a camera. Can be requested with a MAV_CMD_REQUEST_MESSAGE command.

CAMERA_SETTINGS

Implemented types

Constructors

CameraSettings({required uint32_t timeBootMs, required CameraMode modeId, required float zoomlevel, required float focuslevel})
CameraSettings.parse(ByteData data_)
factory

Properties

focuslevel float
Current focus level as a percentage of the full range (0.0 to 100.0, NaN if not known)
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
modeId AccelcalVehiclePos
Camera mode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeBootMs AccelcalVehiclePos
Timestamp (time since system boot).
final
zoomlevel float
Current zoom level as a percentage of the full range (0.0 to 100.0, NaN if not known)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited