CellularStatus class

Report current used cellular network status

CELLULAR_STATUS

Implemented types

Constructors

CellularStatus({required uint16_t mcc, required uint16_t mnc, required uint16_t lac, required CellularStatusFlag status, required CellularNetworkFailedReason failureReason, required CellularNetworkRadioType type, required uint8_t quality})
CellularStatus.parse(ByteData data_)
factory

Properties

failureReason AccelcalVehiclePos
Failure reason when status in in CELLULAR_STATUS_FLAG_FAILED
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
lac AccelcalVehiclePos
Location area code. If unknown, set to 0
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
mcc AccelcalVehiclePos
Mobile country code. If unknown, set to UINT16_MAX
final
mnc AccelcalVehiclePos
Mobile network code. If unknown, set to UINT16_MAX
final
quality AccelcalVehiclePos
Signal quality in percent. If unknown, set to UINT8_MAX
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AccelcalVehiclePos
Cellular modem status
final
type AccelcalVehiclePos
Cellular network radio type: gsm, cdma, lte...
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited