ChangeOperatorControlAck class

Accept / deny control of this MAV

CHANGE_OPERATOR_CONTROL_ACK

Implemented types

Constructors

ChangeOperatorControlAck({required uint8_t gcsSystemId, required uint8_t controlRequest, required uint8_t ack})
ChangeOperatorControlAck.parse(ByteData data_)
factory

Properties

ack AccelcalVehiclePos
0: ACK, 1: NACK: Wrong passkey, 2: NACK: Unsupported passkey encryption method, 3: NACK: Already under control
final
controlRequest AccelcalVehiclePos
0: request control of this MAV, 1: Release control of this MAV
final
gcsSystemId AccelcalVehiclePos
ID of the GCS this message
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited