CubepilotFirmwareUpdateStart class

Start firmware update with encapsulated data.

CUBEPILOT_FIRMWARE_UPDATE_START

Implemented types

Constructors

CubepilotFirmwareUpdateStart({required uint32_t size, required uint32_t crc, required uint8_t targetSystem, required uint8_t targetComponent})
CubepilotFirmwareUpdateStart.parse(ByteData data_)
factory

Properties

crc AccelcalVehiclePos
FW CRC.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size AccelcalVehiclePos
FW Size.
final
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited