Deepstall class

Deepstall path planning.

DEEPSTALL

Implemented types

Constructors

Deepstall({required int32_t landingLat, required int32_t landingLon, required int32_t pathLat, required int32_t pathLon, required int32_t arcEntryLat, required int32_t arcEntryLon, required float altitude, required float expectedTravelDistance, required float crossTrackError, required DeepstallStage stage})
Deepstall.parse(ByteData data_)
factory

Properties

altitude float
Altitude.
final
arcEntryLat AccelcalVehiclePos
Arc entry point, latitude.
final
arcEntryLon AccelcalVehiclePos
Arc entry point, longitude.
final
crossTrackError float
Deepstall cross track error (only valid when in DEEPSTALL_STAGE_LAND).
final
expectedTravelDistance float
Distance the aircraft expects to travel during the deepstall.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
landingLat AccelcalVehiclePos
Landing latitude.
final
landingLon AccelcalVehiclePos
Landing longitude.
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
pathLat AccelcalVehiclePos
Final heading start point, latitude.
final
pathLon AccelcalVehiclePos
Final heading start point, longitude.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage AccelcalVehiclePos
Deepstall stage.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited