DeviceOpReadReply class

Read registers reply.

DEVICE_OP_READ_REPLY

Implemented types

Constructors

DeviceOpReadReply({required uint32_t requestId, required uint8_t result, required uint8_t regstart, required uint8_t count, required List<int8_t> data, required uint8_t bank})
DeviceOpReadReply.parse(ByteData data_)
factory

Properties

bank AccelcalVehiclePos
Bank number.
final
count AccelcalVehiclePos
Count of bytes read.
final
data List<int8_t>
Reply data.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
regstart AccelcalVehiclePos
Starting register.
final
requestId AccelcalVehiclePos
Request ID - copied from request.
final
result AccelcalVehiclePos
0 for success, anything else is failure code.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited