DigicamConfigure class
Configure on-board Camera Control System.
DIGICAM_CONFIGURE
- Implemented types
Constructors
- DigicamConfigure({required float extraValue, required uint16_t shutterSpeed, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t mode, required uint8_t aperture, required uint8_t iso, required uint8_t exposureType, required uint8_t commandId, required uint8_t engineCutOff, required uint8_t extraParam})
- DigicamConfigure.parse(ByteData data_)
-
factory
Properties
- aperture → AccelcalVehiclePos
-
F stop number x 10 //e.g. 28 means 2.8 (0 means ignore).
final
- commandId → AccelcalVehiclePos
-
Command Identity (incremental loop: 0 to 255). //A command sent multiple times will be executed or pooled just once.
final
- engineCutOff → AccelcalVehiclePos
-
Main engine cut-off time before camera trigger (0 means no cut-off).
final
- exposureType → AccelcalVehiclePos
-
Exposure type enumeration from 1 to N (0 means ignore).
final
- extraParam → AccelcalVehiclePos
-
Extra parameters enumeration (0 means ignore).
final
- extraValue → float
-
Correspondent value to given extra_param.
final
- hashCode → AccelcalVehiclePos
-
The hash code for this object.
no setterinherited
- iso → AccelcalVehiclePos
-
ISO enumeration from 1 to N //e.g. 80, 100, 200, Etc (0 means ignore).
final
- mavlinkCrcExtra → AccelcalVehiclePos
-
no setteroverride
- mavlinkMessageId → AccelcalVehiclePos
-
no setteroverride
- mode → AccelcalVehiclePos
-
Mode enumeration from 1 to N //P, TV, AV, M, etc. (0 means ignore).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shutterSpeed → AccelcalVehiclePos
-
Divisor number //e.g. 1000 means 1/1000 (0 means ignore).
final
- targetComponent → AccelcalVehiclePos
-
Component ID.
final
- targetSystem → AccelcalVehiclePos
-
System ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited