DigicamControl class

Control on-board Camera Control System to take shots.

DIGICAM_CONTROL

Implemented types

Constructors

DigicamControl({required float extraValue, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t session, required uint8_t zoomPos, required int8_t zoomStep, required uint8_t focusLock, required uint8_t shot, required uint8_t commandId, required uint8_t extraParam})
DigicamControl.parse(ByteData data_)
factory

Properties

commandId AccelcalVehiclePos
Command Identity (incremental loop: 0 to 255)//A command sent multiple times will be executed or pooled just once.
final
extraParam AccelcalVehiclePos
Extra parameters enumeration (0 means ignore).
final
extraValue float
Correspondent value to given extra_param.
final
focusLock AccelcalVehiclePos
0: unlock focus or keep unlocked, 1: lock focus or keep locked, 3: re-lock focus.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session AccelcalVehiclePos
0: stop, 1: start or keep it up //Session control e.g. show/hide lens.
final
shot AccelcalVehiclePos
0: ignore, 1: shot or start filming.
final
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final
zoomPos AccelcalVehiclePos
1 to N //Zoom's absolute position (0 means ignore).
final
zoomStep AccelcalVehiclePos
-100 to 100 //Zooming step value to offset zoom from the current position.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited