GimbalControl class

Control message for rate gimbal.

GIMBAL_CONTROL

Implemented types

Constructors

GimbalControl({required float demandedRateX, required float demandedRateY, required float demandedRateZ, required uint8_t targetSystem, required uint8_t targetComponent})
GimbalControl.parse(ByteData data_)
factory

Properties

demandedRateX float
Demanded angular rate X.
final
demandedRateY float
Demanded angular rate Y.
final
demandedRateZ float
Demanded angular rate Z.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited