LedControl class

Control vehicle LEDs.

LED_CONTROL

Implemented types

Constructors

LedControl({required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t instance, required uint8_t pattern, required uint8_t customLen, required List<int8_t> customBytes})
LedControl.parse(ByteData data_)
factory

Properties

customBytes List<int8_t>
Custom Bytes.
final
customLen AccelcalVehiclePos
Custom Byte Length.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
instance AccelcalVehiclePos
Instance (LED instance to control or 255 for all LEDs).
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
pattern AccelcalVehiclePos
Pattern (see LED_PATTERN_ENUM).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited