MountControl class

Message to control a camera mount, directional antenna, etc.

MOUNT_CONTROL

Implemented types

Constructors

MountControl({required int32_t inputA, required int32_t inputB, required int32_t inputC, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t savePosition})
MountControl.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
inputA AccelcalVehiclePos
Pitch (centi-degrees) or lat (degE7), depending on mount mode.
final
inputB AccelcalVehiclePos
Roll (centi-degrees) or lon (degE7) depending on mount mode.
final
inputC AccelcalVehiclePos
Yaw (centi-degrees) or alt (cm) depending on mount mode.
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savePosition AccelcalVehiclePos
If "1" it will save current trimmed position on EEPROM (just valid for NEUTRAL and LANDING).
final
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited