PowerStatus class

Power supply status

POWER_STATUS

Implemented types

Constructors

PowerStatus({required uint16_t vcc, required uint16_t vservo, required MavPowerStatus flags})
PowerStatus.parse(ByteData data_)
factory

Properties

flags AccelcalVehiclePos
Bitmap of power supply status flags.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vcc AccelcalVehiclePos
5V rail voltage.
final
vservo AccelcalVehiclePos
Servo rail voltage.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited