RemoteLogBlockStatus class

Send Status of each log block that autopilot board might have sent.

REMOTE_LOG_BLOCK_STATUS

Implemented types

Constructors

RemoteLogBlockStatus({required uint32_t seqno, required uint8_t targetSystem, required uint8_t targetComponent, required MavRemoteLogDataBlockStatuses status})
RemoteLogBlockStatus.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seqno AccelcalVehiclePos
Log data block sequence number.
final
status AccelcalVehiclePos
Log data block status.
final
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited