RemoteLogDataBlock class
Send a block of log data to remote location.
REMOTE_LOG_DATA_BLOCK
- Implemented types
Constructors
-
RemoteLogDataBlock({required MavRemoteLogDataBlockCommands seqno, required uint8_t targetSystem, required uint8_t targetComponent, required List<
int8_t> data}) - RemoteLogDataBlock.parse(ByteData data_)
-
factory
Properties
-
data
→ List<
int8_t> -
Log data block.
final
- hashCode → AccelcalVehiclePos
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → AccelcalVehiclePos
-
no setteroverride
- mavlinkMessageId → AccelcalVehiclePos
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seqno → AccelcalVehiclePos
-
Log data block sequence number.
final
- targetComponent → AccelcalVehiclePos
-
Component ID.
final
- targetSystem → AccelcalVehiclePos
-
System ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited