ResponseEventError class

Response to a REQUEST_EVENT in case of an error (e.g. the event is not available anymore).

RESPONSE_EVENT_ERROR

Implemented types

Constructors

ResponseEventError({required uint16_t sequence, required uint16_t sequenceOldestAvailable, required uint8_t targetSystem, required uint8_t targetComponent, required MavEventErrorReason reason})
ResponseEventError.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
reason AccelcalVehiclePos
Error reason.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence AccelcalVehiclePos
Sequence number.
final
sequenceOldestAvailable AccelcalVehiclePos
Oldest Sequence number that is still available after the sequence set in REQUEST_EVENT.
final
targetComponent AccelcalVehiclePos
Component ID
final
targetSystem AccelcalVehiclePos
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited