SerialControl class

Control a serial port. This can be used for raw access to an onboard serial peripheral such as a GPS or telemetry radio. It is designed to make it possible to update the devices firmware via MAVLink messages or change the devices settings. A message with zero bytes can be used to change just the baudrate.

SERIAL_CONTROL

Implemented types

Constructors

SerialControl({required uint32_t baudrate, required uint16_t timeout, required SerialControlDev device, required SerialControlFlag flags, required uint8_t count, required List<int8_t> data, required uint8_t targetSystem, required uint8_t targetComponent})
SerialControl.parse(ByteData data_)
factory

Properties

baudrate AccelcalVehiclePos
Baudrate of transfer. Zero means no change.
final
count AccelcalVehiclePos
how many bytes in this transfer
final
data List<int8_t>
serial data
final
device AccelcalVehiclePos
Serial control device type.
final
flags AccelcalVehiclePos
Bitmap of serial control flags.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent AccelcalVehiclePos
Component ID
final
targetSystem AccelcalVehiclePos
System ID
final
timeout AccelcalVehiclePos
Timeout for reply data
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited