Simstate class

Status of simulation environment, if used.

SIMSTATE

Implemented types

Constructors

Simstate({required float roll, required float pitch, required float yaw, required float xacc, required float yacc, required float zacc, required float xgyro, required float ygyro, required float zgyro, required int32_t lat, required int32_t lng})
Simstate.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
lat AccelcalVehiclePos
Latitude.
final
lng AccelcalVehiclePos
Longitude.
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
pitch float
Pitch angle.
final
roll float
Roll angle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xacc float
X acceleration.
final
xgyro float
Angular speed around X axis.
final
yacc float
Y acceleration.
final
yaw float
Yaw angle.
final
ygyro float
Angular speed around Y axis.
final
zacc float
Z acceleration.
final
zgyro float
Angular speed around Z axis.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited