VideoStreamStatus class

Information about the status of a video stream. It may be requested using MAV_CMD_REQUEST_MESSAGE.

VIDEO_STREAM_STATUS

Implemented types

Constructors

VideoStreamStatus({required float framerate, required uint32_t bitrate, required VideoStreamStatusFlags flags, required uint16_t resolutionH, required uint16_t resolutionV, required uint16_t rotation, required uint16_t hfov, required uint8_t streamId})
VideoStreamStatus.parse(ByteData data_)
factory

Properties

bitrate AccelcalVehiclePos
Bit rate
final
flags AccelcalVehiclePos
Bitmap of stream status flags
final
framerate float
Frame rate
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
hfov AccelcalVehiclePos
Horizontal Field of view
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
resolutionH AccelcalVehiclePos
Horizontal resolution
final
resolutionV AccelcalVehiclePos
Vertical resolution
final
rotation AccelcalVehiclePos
Video image rotation clockwise
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId AccelcalVehiclePos
Video Stream ID (1 for first, 2 for second, etc.)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited