VisionPositionDelta class

Camera vision based attitude and position deltas.

VISION_POSITION_DELTA

Implemented types

Constructors

VisionPositionDelta({required uint64_t timeUsec, required uint64_t timeDeltaUsec, required List<float> angleDelta, required List<float> positionDelta, required float confidence})
VisionPositionDelta.parse(ByteData data_)
factory

Properties

angleDelta List<float>
Defines a rotation vector roll, pitch, yaw to the current MAV_FRAME_BODY_FRD from the previous MAV_FRAME_BODY_FRD.
final
confidence float
Normalised confidence value from 0 to 100.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
positionDelta List<float>
Change in position to the current MAV_FRAME_BODY_FRD from the previous FRAME_BODY_FRD rotated to the current MAV_FRAME_BODY_FRD.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeDeltaUsec AccelcalVehiclePos
Time since the last reported camera frame.
final
timeUsec AccelcalVehiclePos
Timestamp (synced to UNIX time or since system boot).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited