WaterDepth class

Water depth

WATER_DEPTH

Implemented types

Constructors

WaterDepth({required uint32_t timeBootMs, required int32_t lat, required int32_t lng, required float alt, required float roll, required float pitch, required float yaw, required float distance, required float temperature, required uint8_t id, required uint8_t healthy})
WaterDepth.parse(ByteData data_)
factory

Properties

alt float
Altitude (MSL) of vehicle
final
distance float
Distance (uncorrected)
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
healthy AccelcalVehiclePos
Sensor data healthy (0=unhealthy, 1=healthy)
final
id AccelcalVehiclePos
Onboard ID of the sensor
final
lat AccelcalVehiclePos
Latitude
final
lng AccelcalVehiclePos
Longitude
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
pitch float
Pitch angle
final
roll float
Roll angle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature float
Water temperature
final
timeBootMs AccelcalVehiclePos
Timestamp (time since system boot)
final
yaw float
Yaw angle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited