command property
The scheduled action for the mission item, as defined by MAV_CMD enum
MAVLink type: uint16_t
enum: MavCmd
command
Implementation
final MavCmd command;
The scheduled action for the mission item, as defined by MAV_CMD enum
MAVLink type: uint16_t
enum: MavCmd
command
final MavCmd command;