CommandLongStamped class

Send a command with up to seven parameters to the MAV and additional metadata

COMMAND_LONG_STAMPED

Implemented types

Constructors

CommandLongStamped({required uint64_t vehicleTimestamp, required uint32_t utcTime, required float param1, required float param2, required float param3, required float param4, required float param5, required float param6, required float param7, required MavCmd command, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t confirmation})
CommandLongStamped.parse(ByteData data_)
factory

Properties

command ActuatorConfiguration
Command ID, as defined by MAV_CMD enum.
final
confirmation ActuatorConfiguration
0: First transmission of this command. 1-255: Confirmation transmissions (e.g. for kill command)
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
param1 float
Parameter 1, as defined by MAV_CMD enum.
final
param2 float
Parameter 2, as defined by MAV_CMD enum.
final
param3 float
Parameter 3, as defined by MAV_CMD enum.
final
param4 float
Parameter 4, as defined by MAV_CMD enum.
final
param5 float
Parameter 5, as defined by MAV_CMD enum.
final
param6 float
Parameter 6, as defined by MAV_CMD enum.
final
param7 float
Parameter 7, as defined by MAV_CMD enum.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component which should execute the command, 0 for all components
final
targetSystem ActuatorConfiguration
System which should execute the command
final
utcTime ActuatorConfiguration
UTC time, seconds elapsed since 01.01.1970
final
vehicleTimestamp ActuatorConfiguration
Microseconds elapsed since vehicle boot
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited