SensorAirflowAngles class

Calibrated airflow angle measurements

SENSOR_AIRFLOW_ANGLES

Implemented types

Constructors

SensorAirflowAngles({required uint64_t timestamp, required float angleofattack, required float sideslip, required uint8_t angleofattackValid, required uint8_t sideslipValid})
SensorAirflowAngles.parse(ByteData data_)
factory

Properties

angleofattack float
Angle of attack
final
angleofattackValid ActuatorConfiguration
Angle of attack measurement valid
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sideslip float
Sideslip angle
final
sideslipValid ActuatorConfiguration
Sideslip angle measurement valid
final
timestamp ActuatorConfiguration
Timestamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited