AuthKey class
Emit an encrypted signature / key identifying this system. PLEASE NOTE: This protocol has been kept simple, so transmitting the key requires an encrypted channel for true safety.
AUTH_KEY
- Implemented types
Constructors
-
AuthKey({required List<
int8_t> key}) - AuthKey.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
-
key
→ List<
int8_t> -
key
final
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited