ButtonChange class

Report button state change.

BUTTON_CHANGE

Implemented types

Constructors

ButtonChange({required uint32_t timeBootMs, required uint32_t lastChangeMs, required uint8_t state})
ButtonChange.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
lastChangeMs ActuatorConfiguration
Time of last change of button state.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ActuatorConfiguration
Bitmap for state of buttons.
final
timeBootMs ActuatorConfiguration
Timestamp (time since system boot).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited