CameraCaptureStatus class

Information about the status of a capture. Can be requested with a MAV_CMD_REQUEST_MESSAGE command.

CAMERA_CAPTURE_STATUS

Implemented types

Constructors

CameraCaptureStatus({required uint32_t timeBootMs, required float imageInterval, required uint32_t recordingTimeMs, required float availableCapacity, required uint8_t imageStatus, required uint8_t videoStatus, required int32_t imageCount})
CameraCaptureStatus.parse(ByteData data_)
factory

Properties

availableCapacity float
Available storage capacity.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
imageCount ActuatorConfiguration
Total number of images captured ('forever', or until reset using MAV_CMD_STORAGE_FORMAT).
final
imageInterval float
Image capture interval
final
imageStatus ActuatorConfiguration
Current status of image capturing (0: idle, 1: capture in progress, 2: interval set but idle, 3: interval set and capture in progress)
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
recordingTimeMs ActuatorConfiguration
Elapsed time since recording started (0: Not supported/available). A GCS should compute recording time and use non-zero values of this field to correct any discrepancy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeBootMs ActuatorConfiguration
Timestamp (time since system boot).
final
videoStatus ActuatorConfiguration
Current status of video capturing (0: idle, 1: capture in progress)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited