Debug class
Send a debug value. The index is used to discriminate between values. These values show up in the plot of QGroundControl as DEBUG N.
DEBUG
- Implemented types
Constructors
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- ind → ActuatorConfiguration
-
index of debug variable
final
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeBootMs → ActuatorConfiguration
-
Timestamp (time since system boot).
final
- value → float
-
DEBUG value
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited