Event class

Event message. Each new event from a particular component gets a new sequence number. The same message might be sent multiple times if (re-)requested. Most events are broadcast, some can be specific to a target component (as receivers keep track of the sequence for missed events, all events need to be broadcast. Thus we use destination_component instead of target_component).

EVENT

Implemented types

Constructors

Event({required uint32_t id, required uint32_t eventTimeBootMs, required uint16_t sequence, required uint8_t destinationComponent, required uint8_t destinationSystem, required uint8_t logLevels, required List<int8_t> arguments})
Event.parse(ByteData data_)
factory

Properties

arguments List<int8_t>
Arguments (depend on event ID).
final
destinationComponent ActuatorConfiguration
Component ID
final
destinationSystem ActuatorConfiguration
System ID
final
eventTimeBootMs ActuatorConfiguration
Timestamp (time since system boot when the event happened).
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
id ActuatorConfiguration
Event ID (as defined in the component metadata)
final
logLevels ActuatorConfiguration
Log levels: 4 bits MSB: internal (for logging purposes), 4 bits LSB: external. Levels: Emergency = 0, Alert = 1, Critical = 2, Error = 3, Warning = 4, Notice = 5, Info = 6, Debug = 7, Protocol = 8, Disabled = 9
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence ActuatorConfiguration
Sequence number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited