GlobalPositionInt class

The filtered global position (e.g. fused GPS and accelerometers). The position is in GPS-frame (right-handed, Z-up). It is designed as scaled integer message since the resolution of float is not sufficient.

GLOBAL_POSITION_INT

Implemented types

Constructors

GlobalPositionInt({required uint32_t timeBootMs, required int32_t lat, required int32_t lon, required int32_t alt, required int32_t relativeAlt, required int16_t vx, required int16_t vy, required int16_t vz, required uint16_t hdg})
GlobalPositionInt.parse(ByteData data_)
factory

Properties

alt ActuatorConfiguration
Altitude (MSL). Note that virtually all GPS modules provide both WGS84 and MSL.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
hdg ActuatorConfiguration
Vehicle heading (yaw angle), 0.0..359.99 degrees. If unknown, set to: UINT16_MAX
final
lat ActuatorConfiguration
Latitude, expressed
final
lon ActuatorConfiguration
Longitude, expressed
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
relativeAlt ActuatorConfiguration
Altitude above ground
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeBootMs ActuatorConfiguration
Timestamp (time since system boot).
final
vx ActuatorConfiguration
Ground X Speed (Latitude, positive north)
final
vy ActuatorConfiguration
Ground Y Speed (Longitude, positive east)
final
vz ActuatorConfiguration
Ground Z Speed (Altitude, positive down)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited