IsbdLinkStatus class

Status of the Iridium SBD link.

ISBD_LINK_STATUS

Implemented types

Constructors

IsbdLinkStatus({required uint64_t timestamp, required uint64_t lastHeartbeat, required uint16_t failedSessions, required uint16_t successfulSessions, required uint8_t signalQuality, required uint8_t ringPending, required uint8_t txSessionPending, required uint8_t rxSessionPending})
IsbdLinkStatus.parse(ByteData data_)
factory

Properties

failedSessions ActuatorConfiguration
Number of failed SBD sessions.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
lastHeartbeat ActuatorConfiguration
Timestamp of the last successful sbd session. The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
ringPending ActuatorConfiguration
1: Ring call pending, 0: No call pending.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rxSessionPending ActuatorConfiguration
1: Receiving session pending, 0: No receiving session pending.
final
signalQuality ActuatorConfiguration
Signal quality equal to the number of bars displayed on the ISU signal strength indicator. Range is 0 to 5, where 0 indicates no signal and 5 indicates maximum signal strength.
final
successfulSessions ActuatorConfiguration
Number of successful SBD sessions.
final
timestamp ActuatorConfiguration
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final
txSessionPending ActuatorConfiguration
1: Transmission session pending, 0: No transmission session pending.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited