LoggingData class
A message containing logged data (see also MAV_CMD_LOGGING_START)
LOGGING_DATA
- Implemented types
Constructors
-
LoggingData({required uint16_t sequence, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t length, required uint8_t firstMessageOffset, required List<
int8_t> data}) - LoggingData.parse(ByteData data_)
-
factory
Properties
-
data
→ List<
int8_t> -
logged data
final
- firstMessageOffset → ActuatorConfiguration
-
offset into data where first message starts. This can be used for recovery, when a previous message got lost (set to UINT8_MAX if no start exists).
final
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- length → ActuatorConfiguration
-
data length
final
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → ActuatorConfiguration
-
sequence number (can wrap)
final
- targetComponent → ActuatorConfiguration
-
component ID of the target
final
- targetSystem → ActuatorConfiguration
-
system ID of the target
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited