MemoryVect class

Send raw controller memory. The use of this message is discouraged for normal packets, but a quite efficient way for testing new messages and getting experimental debug output.

MEMORY_VECT

Implemented types

Constructors

MemoryVect({required uint16_t address, required uint8_t ver, required uint8_t type, required List<int8_t> value})
MemoryVect.parse(ByteData data_)
factory

Properties

address ActuatorConfiguration
Starting address of the debug variables
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ActuatorConfiguration
Type code of the memory variables. for ver = 1: 0=16 x int16_t, 1=16 x uint16_t, 2=16 x Q15, 3=16 x 1Q14
final
value List<int8_t>
Memory contents at specified address
final
ver ActuatorConfiguration
Version code of the type variable. 0=unknown, type ignored and assumed int16_t. 1=as below
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited