MissionWritePartialList class

This message is sent to the MAV to write a partial list. If start index == end index, only one item will be transmitted / updated. If the start index is NOT 0 and above the current list size, this request should be REJECTED!

MISSION_WRITE_PARTIAL_LIST

Implemented types

Constructors

MissionWritePartialList({required int16_t startIndex, required int16_t endIndex, required uint8_t targetSystem, required uint8_t targetComponent, required MavMissionType missionType})
MissionWritePartialList.parse(ByteData data_)
factory

Properties

endIndex ActuatorConfiguration
End index, equal or greater than start index.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
missionType ActuatorConfiguration
Mission type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startIndex ActuatorConfiguration
Start index. Must be smaller / equal to the largest index of the current onboard list.
final
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited