NavControllerOutput class

The state of the navigation and position controller.

NAV_CONTROLLER_OUTPUT

Implemented types

Constructors

factory

Properties

altError float
Current altitude error
final
aspdError float
Current airspeed error
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
Current desired heading
final
Current desired pitch
final
Current desired roll
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetBearing ActuatorConfiguration
Bearing to current waypoint/target
final
wpDist ActuatorConfiguration
Distance to active waypoint
final
xtrackError float
Current crosstrack error on x-y plane
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited