ParamExtRequestList class

Request all parameters of this component. All parameters should be emitted in response as PARAM_EXT_VALUE.

PARAM_EXT_REQUEST_LIST

Implemented types

Constructors

ParamExtRequestList({required uint8_t targetSystem, required uint8_t targetComponent})
ParamExtRequestList.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited