ParamExtValue class

Emit the value of a parameter. The inclusion of param_count and param_index in the message allows the recipient to keep track of received parameters and allows them to re-request missing parameters after a loss or timeout.

PARAM_EXT_VALUE

Implemented types

Constructors

ParamExtValue({required uint16_t paramCount, required uint16_t paramIndex, required List<int8_t> paramId, required List<int8_t> paramValue, required MavParamExtType paramType})
ParamExtValue.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
paramCount ActuatorConfiguration
Total number of parameters
final
paramId List<int8_t>
Parameter id, terminated by NULL if the length is less than 16 human-readable chars and WITHOUT null termination (NULL) byte if the length is exactly 16 chars - applications have to provide 16+1 bytes storage if the ID is stored as string
final
paramIndex ActuatorConfiguration
Index of this parameter
final
paramType ActuatorConfiguration
Parameter type.
final
paramValue List<int8_t>
Parameter value
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited