ProtocolVersion class

Version and capability of protocol version. This message can be requested with MAV_CMD_REQUEST_MESSAGE and is used as part of the handshaking to establish which MAVLink version should be used on the network. Every node should respond to a request for PROTOCOL_VERSION to enable the handshaking. Library implementers should consider adding this into the default decoding state machine to allow the protocol core to respond directly.

PROTOCOL_VERSION

Implemented types

Constructors

ProtocolVersion({required uint16_t version, required uint16_t minVersion, required uint16_t maxVersion, required List<int8_t> specVersionHash, required List<int8_t> libraryVersionHash})
ProtocolVersion.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
libraryVersionHash List<int8_t>
The first 8 bytes (not characters printed in hex!) of the git hash.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
maxVersion ActuatorConfiguration
Maximum MAVLink version supported (set to the same value as version by default)
final
minVersion ActuatorConfiguration
Minimum MAVLink version supported
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specVersionHash List<int8_t>
The first 8 bytes (not characters printed in hex!) of the git hash.
final
version ActuatorConfiguration
Currently active MAVLink version number * 100: v1.0 is 100, v2.0 is 200, etc.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited