RequestDataStream class

Request a data stream.

REQUEST_DATA_STREAM

Implemented types

Constructors

RequestDataStream({required uint16_t reqMessageRate, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t reqStreamId, required uint8_t startStop})
RequestDataStream.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
reqMessageRate ActuatorConfiguration
The requested message rate
final
reqStreamId ActuatorConfiguration
The ID of the requested data stream
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startStop ActuatorConfiguration
1 to start sending, 0 to stop sending.
final
targetComponent ActuatorConfiguration
The target requested to send the message stream.
final
targetSystem ActuatorConfiguration
The target requested to send the message stream.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited