SerialControl class

Control a serial port. This can be used for raw access to an onboard serial peripheral such as a GPS or telemetry radio. It is designed to make it possible to update the devices firmware via MAVLink messages or change the devices settings. A message with zero bytes can be used to change just the baudrate.

SERIAL_CONTROL

Implemented types

Constructors

SerialControl({required uint32_t baudrate, required uint16_t timeout, required SerialControlDev device, required SerialControlFlag flags, required uint8_t count, required List<int8_t> data, required uint8_t targetSystem, required uint8_t targetComponent})
SerialControl.parse(ByteData data_)
factory

Properties

baudrate ActuatorConfiguration
Baudrate of transfer. Zero means no change.
final
count ActuatorConfiguration
how many bytes in this transfer
final
data List<int8_t>
serial data
final
device ActuatorConfiguration
Serial control device type.
final
flags ActuatorConfiguration
Bitmap of serial control flags.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final
timeout ActuatorConfiguration
Timeout for reply data
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited