SetupSigning class

Setup a MAVLink2 signing key. If called with secret_key of all zero and zero initial_timestamp will disable signing

SETUP_SIGNING

Implemented types

Constructors

SetupSigning({required uint64_t initialTimestamp, required uint8_t targetSystem, required uint8_t targetComponent, required List<int8_t> secretKey})
SetupSigning.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
initialTimestamp ActuatorConfiguration
initial timestamp
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey List<int8_t>
signing key
final
targetComponent ActuatorConfiguration
component ID of the target
final
targetSystem ActuatorConfiguration
system id of the target
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited