SysStatus class

The general system state. If the system is following the MAVLink standard, the system state is mainly defined by three orthogonal states/modes: The system mode, which is either LOCKED (motors shut down and locked), MANUAL (system under RC control), GUIDED (system with autonomous position control, position setpoint controlled manually) or AUTO (system guided by path/waypoint planner). The NAV_MODE defined the current flight state: LIFTOFF (often an open-loop maneuver), LANDING, WAYPOINTS or VECTOR. This represents the internal navigation state machine. The system status shows whether the system is currently active or not and if an emergency occurred. During the CRITICAL and EMERGENCY states the MAV is still considered to be active, but should start emergency procedures autonomously. After a failure occurred it should first move from active to critical to allow manual intervention and then move to emergency after a certain timeout.

SYS_STATUS

Implemented types

Constructors

SysStatus({required MavSysStatusSensor onboardControlSensorsPresent, required MavSysStatusSensor onboardControlSensorsEnabled, required MavSysStatusSensor onboardControlSensorsHealth, required uint16_t load, required uint16_t voltageBattery, required int16_t currentBattery, required uint16_t dropRateComm, required uint16_t errorsComm, required uint16_t errorsCount1, required uint16_t errorsCount2, required uint16_t errorsCount3, required uint16_t errorsCount4, required int8_t batteryRemaining, required MavSysStatusSensorExtended onboardControlSensorsPresentExtended, required MavSysStatusSensorExtended onboardControlSensorsEnabledExtended, required MavSysStatusSensorExtended onboardControlSensorsHealthExtended})
SysStatus.parse(ByteData data_)
factory

Properties

batteryRemaining ActuatorConfiguration
Battery energy remaining, -1: Battery remaining energy not sent by autopilot
final
currentBattery ActuatorConfiguration
Battery current, -1: Current not sent by autopilot
final
dropRateComm ActuatorConfiguration
Communication drop rate, (UART, I2C, SPI, CAN), dropped packets on all links (packets that were corrupted on reception on the MAV)
final
errorsComm ActuatorConfiguration
Communication errors (UART, I2C, SPI, CAN), dropped packets on all links (packets that were corrupted on reception on the MAV)
final
errorsCount1 ActuatorConfiguration
Autopilot-specific errors
final
errorsCount2 ActuatorConfiguration
Autopilot-specific errors
final
errorsCount3 ActuatorConfiguration
Autopilot-specific errors
final
errorsCount4 ActuatorConfiguration
Autopilot-specific errors
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
load ActuatorConfiguration
Maximum usage in percent of the mainloop time. Values: 0-1000 - should always be below 1000
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
onboardControlSensorsEnabled ActuatorConfiguration
Bitmap showing which onboard controllers and sensors are enabled: Value of 0: not enabled. Value of 1: enabled.
final
onboardControlSensorsEnabledExtended ActuatorConfiguration
Bitmap showing which onboard controllers and sensors are enabled: Value of 0: not enabled. Value of 1: enabled.
final
onboardControlSensorsHealth ActuatorConfiguration
Bitmap showing which onboard controllers and sensors have an error (or are operational). Value of 0: error. Value of 1: healthy.
final
onboardControlSensorsHealthExtended ActuatorConfiguration
Bitmap showing which onboard controllers and sensors have an error (or are operational). Value of 0: error. Value of 1: healthy.
final
onboardControlSensorsPresent ActuatorConfiguration
Bitmap showing which onboard controllers and sensors are present. Value of 0: not present. Value of 1: present.
final
onboardControlSensorsPresentExtended ActuatorConfiguration
Bitmap showing which onboard controllers and sensors are present. Value of 0: not present. Value of 1: present.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voltageBattery ActuatorConfiguration
Battery voltage, UINT16_MAX: Voltage not sent by autopilot
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited