VideoStreamInformation class

Information about video stream. It may be requested using MAV_CMD_REQUEST_MESSAGE, where param2 indicates the video stream id: 0 for all streams, 1 for first, 2 for second, etc.

VIDEO_STREAM_INFORMATION

Implemented types

Constructors

VideoStreamInformation({required float framerate, required uint32_t bitrate, required VideoStreamStatusFlags flags, required uint16_t resolutionH, required uint16_t resolutionV, required uint16_t rotation, required uint16_t hfov, required uint8_t streamId, required uint8_t count, required VideoStreamType type, required List<int8_t> name, required List<int8_t> uri})
VideoStreamInformation.parse(ByteData data_)
factory

Properties

bitrate ActuatorConfiguration
Bit rate.
final
count ActuatorConfiguration
Number of streams available.
final
flags ActuatorConfiguration
Bitmap of stream status flags.
final
framerate float
Frame rate.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
hfov ActuatorConfiguration
Horizontal Field of view.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
name List<int8_t>
Stream name.
final
resolutionH ActuatorConfiguration
Horizontal resolution.
final
resolutionV ActuatorConfiguration
Vertical resolution.
final
rotation ActuatorConfiguration
Video image rotation clockwise.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId ActuatorConfiguration
Video Stream ID (1 for first, 2 for second, etc.)
final
type ActuatorConfiguration
Type of stream.
final
uri List<int8_t>
Video stream URI (TCP or RTSP URI ground station should connect to) or port number (UDP port ground station should listen to).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited