CubepilotFirmwareUpdateStart class

Start firmware update with encapsulated data.

CUBEPILOT_FIRMWARE_UPDATE_START

Implemented types

Constructors

CubepilotFirmwareUpdateStart({required uint32_t size, required uint32_t crc, required uint8_t targetSystem, required uint8_t targetComponent})
CubepilotFirmwareUpdateStart.parse(ByteData data_)
factory

Properties

crc ActuatorConfiguration
FW CRC.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ActuatorConfiguration
FW Size.
final
targetComponent ActuatorConfiguration
Component ID.
final
targetSystem ActuatorConfiguration
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited