Airspeed class

Airspeed information from a sensor.

AIRSPEED

Implemented types

Constructors

Airspeed({required float airspeed, required float rawPress, required int16_t temperature, required uint8_t id, required AirspeedSensorFlags flags})
Airspeed.parse(ByteData data_)
factory

Properties

airspeed float
Calibrated airspeed (CAS).
final
flags ActuatorConfiguration
Airspeed sensor flags.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
id ActuatorConfiguration
Sensor ID.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
rawPress float
Raw differential pressure. NaN for value unknown/not supplied.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature ActuatorConfiguration
Temperature. INT16_MAX for value unknown/not supplied.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited