AttPosMocap class

Motion capture attitude and position

ATT_POS_MOCAP

Implemented types

Constructors

AttPosMocap({required uint64_t timeUsec, required List<float> q, required float x, required float y, required float z, required List<float> covariance})
AttPosMocap.parse(ByteData data_)
factory

Properties

covariance List<float>
Row-major representation of a pose 6x6 cross-covariance matrix upper right triangle (states: x, y, z, roll, pitch, yaw; first six entries are the first ROW, next five entries are the second ROW, etc.). If unknown, assign NaN value to first element in the array.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
q List<float>
Attitude quaternion (w, x, y, z order, zero-rotation is 1, 0, 0, 0)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeUsec ActuatorConfiguration
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final
x float
X position (NED)
final
y float
Y position (NED)
final
z float
Z position (NED)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited