AutopilotVersion class

Version and capability of autopilot software. This should be emitted in response to a request with MAV_CMD_REQUEST_MESSAGE.

AUTOPILOT_VERSION

Implemented types

Constructors

AutopilotVersion({required MavProtocolCapability capabilities, required uint64_t uid, required uint32_t flightSwVersion, required uint32_t middlewareSwVersion, required uint32_t osSwVersion, required uint32_t boardVersion, required uint16_t vendorId, required uint16_t productId, required List<int8_t> flightCustomVersion, required List<int8_t> middlewareCustomVersion, required List<int8_t> osCustomVersion, required List<int8_t> uid2})
AutopilotVersion.parse(ByteData data_)
factory

Properties

boardVersion ActuatorConfiguration
HW / board version (last 8 bits should be silicon ID, if any). The first 16 bits of this field specify https://github.com/PX4/PX4-Bootloader/blob/master/board_types.txt
final
capabilities ActuatorConfiguration
Bitmap of capabilities
final
flightCustomVersion List<int8_t>
Custom version field, commonly the first 8 bytes of the git hash. This is not an unique identifier, but should allow to identify the commit using the main version number even for very large code bases.
final
flightSwVersion ActuatorConfiguration
Firmware version number
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
middlewareCustomVersion List<int8_t>
Custom version field, commonly the first 8 bytes of the git hash. This is not an unique identifier, but should allow to identify the commit using the main version number even for very large code bases.
final
middlewareSwVersion ActuatorConfiguration
Middleware version number
final
osCustomVersion List<int8_t>
Custom version field, commonly the first 8 bytes of the git hash. This is not an unique identifier, but should allow to identify the commit using the main version number even for very large code bases.
final
osSwVersion ActuatorConfiguration
Operating system version number
final
productId ActuatorConfiguration
ID of the product
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uid ActuatorConfiguration
UID if provided by hardware (see uid2)
final
uid2 List<int8_t>
UID if provided by hardware (supersedes the uid field. If this is non-zero, use this field, otherwise use uid)
final
vendorId ActuatorConfiguration
ID of the board vendor
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited