AvailableModes class

Get information about a particular flight modes. The message can be enumerated or requested for a particular mode using MAV_CMD_REQUEST_MESSAGE. Specify 0 in param2 to request that the message is emitted for all available modes or the specific index for just one mode. The modes must be available/settable for the current vehicle/frame type. Each modes should only be emitted once (even if it is both standard and custom).

AVAILABLE_MODES

Implemented types

Constructors

AvailableModes({required uint32_t customMode, required MavModeProperty properties, required uint8_t numberModes, required uint8_t modeIndex, required MavStandardMode standardMode, required List<int8_t> modeName})
AvailableModes.parse(ByteData data_)
factory

Properties

customMode ActuatorConfiguration
A bitfield for use for autopilot-specific flags
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
modeIndex ActuatorConfiguration
The current mode index within number_modes, indexed from 1.
final
modeName List<int8_t>
Name of custom mode, with null termination character. Should be omitted for standard modes.
final
numberModes ActuatorConfiguration
The total number of available modes for the current vehicle type.
final
properties ActuatorConfiguration
Mode properties.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
standardMode ActuatorConfiguration
Standard mode.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited