CanfdFrame class

A forwarded CANFD frame as requested by MAV_CMD_CAN_FORWARD. These are separated from CAN_FRAME as they need different handling (eg. TAO handling)

CANFD_FRAME

Implemented types

Constructors

CanfdFrame({required uint32_t id, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t bus, required uint8_t len, required List<int8_t> data})
CanfdFrame.parse(ByteData data_)
factory

Properties

bus ActuatorConfiguration
bus number
final
data List<int8_t>
Frame data
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
id ActuatorConfiguration
Frame ID
final
len ActuatorConfiguration
Frame length
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID.
final
targetSystem ActuatorConfiguration
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited