CommandAck class

Report status of a command. Includes feedback whether the command was executed. The command microservice is documented at https://mavlink.io/en/services/command.html

COMMAND_ACK

Implemented types

Constructors

CommandAck({required MavCmd command, required MavResult result, required uint8_t progress, required int32_t resultParam2, required uint8_t targetSystem, required uint8_t targetComponent})
CommandAck.parse(ByteData data_)
factory

Properties

command ActuatorConfiguration
Command ID (of acknowledged command).
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
progress ActuatorConfiguration
The progress percentage when result is MAV_RESULT_IN_PROGRESS. Values: 0-100, or UINT8_MAX if the progress is unknown.
final
result ActuatorConfiguration
Result of command.
final
resultParam2 ActuatorConfiguration
Additional result information. Can be set with a command-specific enum containing command-specific error reasons for why the command might be denied. If used, the associated enum must be documented in the corresponding MAV_CMD (this enum should have a 0 value to indicate "unused" or "unknown").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID of the target recipient. This is the ID of the system that sent the command for which this COMMAND_ACK is an acknowledgement.
final
targetSystem ActuatorConfiguration
System ID of the target recipient. This is the ID of the system that sent the command for which this COMMAND_ACK is an acknowledgement.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited