CommandCancel class

Cancel a long running command. The target system should respond with a COMMAND_ACK to the original command with result=MAV_RESULT_CANCELLED if the long running process was cancelled. If it has already completed, the cancel action can be ignored. The cancel action can be retried until some sort of acknowledgement to the original command has been received. The command microservice is documented at https://mavlink.io/en/services/command.html

COMMAND_CANCEL

Implemented types

Constructors

CommandCancel({required MavCmd command, required uint8_t targetSystem, required uint8_t targetComponent})
CommandCancel.parse(ByteData data_)
factory

Properties

command ActuatorConfiguration
Command ID (of command to cancel).
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component executing long running command.
final
targetSystem ActuatorConfiguration
System executing long running command. Should not be broadcast (0).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited