CurrentEventSequence class

Regular broadcast for the current latest event sequence number for a component. This is used to check for dropped events.

CURRENT_EVENT_SEQUENCE

Implemented types

Constructors

CurrentEventSequence({required uint16_t sequence, required MavEventCurrentSequenceFlags flags})
CurrentEventSequence.parse(ByteData data_)
factory

Properties

flags ActuatorConfiguration
Flag bitset.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence ActuatorConfiguration
Sequence number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited