FenceStatus class

Status of geo-fencing. Sent in extended status stream when fencing enabled.

FENCE_STATUS

Implemented types

Constructors

FenceStatus({required uint32_t breachTime, required uint16_t breachCount, required uint8_t breachStatus, required FenceBreach breachType, required FenceMitigate breachMitigation})
FenceStatus.parse(ByteData data_)
factory

Properties

breachCount ActuatorConfiguration
Number of fence breaches.
final
breachMitigation ActuatorConfiguration
Active action to prevent fence breach
final
breachStatus ActuatorConfiguration
Breach status (0 if currently inside fence, 1 if outside).
final
breachTime ActuatorConfiguration
Time (since boot) of last breach.
final
breachType ActuatorConfiguration
Last breach type.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited