FileTransferProtocol class
File transfer protocol message: https://mavlink.io/en/services/ftp.html.
FILE_TRANSFER_PROTOCOL
- Implemented types
Constructors
-
FileTransferProtocol({required uint8_t targetNetwork, required uint8_t targetSystem, required uint8_t targetComponent, required List<
int8_t> payload}) - FileTransferProtocol.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
-
payload
→ List<
int8_t> -
Variable length payload. The length is defined by the remaining message length when subtracting the header and other fields. The content/format of this block is defined in https://mavlink.io/en/services/ftp.html.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetComponent → ActuatorConfiguration
-
Component ID (0 for broadcast)
final
- targetNetwork → ActuatorConfiguration
-
Network ID (0 for broadcast)
final
- targetSystem → ActuatorConfiguration
-
System ID (0 for broadcast)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited