FlightInformation class

Flight information. This includes time since boot for arm, takeoff, and land, and a flight number. Takeoff and landing values reset to zero on arm. This can be requested using MAV_CMD_REQUEST_MESSAGE. Note, some fields are misnamed - timestamps are from boot (not UTC) and the flight_uuid is a sequence number.

FLIGHT_INFORMATION

Implemented types

Constructors

FlightInformation({required uint64_t armingTimeUtc, required uint64_t takeoffTimeUtc, required uint64_t flightUuid, required uint32_t timeBootMs, required uint32_t landingTime})
FlightInformation.parse(ByteData data_)
factory

Properties

armingTimeUtc ActuatorConfiguration
Timestamp at arming (since system boot). Set to 0 on boot. Set value on arming. Note, field is misnamed UTC.
final
flightUuid ActuatorConfiguration
Flight number. Note, field is misnamed UUID.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
landingTime ActuatorConfiguration
Timestamp at landing (in ms since system boot). Set to 0 at boot and on arming.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
takeoffTimeUtc ActuatorConfiguration
Timestamp at takeoff (since system boot). Set to 0 at boot and on arming. Note, field is misnamed UTC.
final
timeBootMs ActuatorConfiguration
Timestamp (time since system boot).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited