FollowTarget class

Current motion information from a designated system

FOLLOW_TARGET

Implemented types

Constructors

FollowTarget({required uint64_t timestamp, required uint64_t customState, required int32_t lat, required int32_t lon, required float alt, required List<float> vel, required List<float> acc, required List<float> attitudeQ, required List<float> rates, required List<float> positionCov, required uint8_t estCapabilities})
FollowTarget.parse(ByteData data_)
factory

Properties

acc List<float>
linear target acceleration (0,0,0) for unknown
final
alt float
Altitude (MSL)
final
attitudeQ List<float>
(0 0 0 0 for unknown)
final
customState ActuatorConfiguration
button states or switches of a tracker device
final
estCapabilities ActuatorConfiguration
bit positions for tracker reporting capabilities (POS = 0, VEL = 1, ACCEL = 2, ATT + RATES = 3)
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
lat ActuatorConfiguration
Latitude (WGS84)
final
lon ActuatorConfiguration
Longitude (WGS84)
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
positionCov List<float>
eph epv
final
rates List<float>
(0 0 0 for unknown)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp ActuatorConfiguration
Timestamp (time since system boot).
final
vel List<float>
target velocity (0,0,0) for unknown
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited