GpsInjectData class

Data for injecting into the onboard GPS (used for DGPS)

GPS_INJECT_DATA

Implemented types

Constructors

GpsInjectData({required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t len, required List<int8_t> data})
GpsInjectData.parse(ByteData data_)
factory

Properties

data List<int8_t>
Raw data (110 is enough for 12 satellites of RTCMv2)
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
len ActuatorConfiguration
Data length
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited