GpsInput class

GPS sensor input message. This is a raw sensor value sent by the GPS. This is NOT the global position estimate of the system.

GPS_INPUT

Implemented types

Constructors

GpsInput({required uint64_t timeUsec, required uint32_t timeWeekMs, required int32_t lat, required int32_t lon, required float alt, required float hdop, required float vdop, required float vn, required float ve, required float vd, required float speedAccuracy, required float horizAccuracy, required float vertAccuracy, required GpsInputIgnoreFlags ignoreFlags, required uint16_t timeWeek, required uint8_t gpsId, required uint8_t fixType, required uint8_t satellitesVisible, required uint16_t yaw})
GpsInput.parse(ByteData data_)
factory

Properties

alt float
Altitude (MSL). Positive for up.
final
fixType ActuatorConfiguration
0-1: no fix, 2: 2D fix, 3: 3D fix. 4: 3D with DGPS. 5: 3D with RTK
final
gpsId ActuatorConfiguration
ID of the GPS for multiple GPS inputs
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
hdop float
GPS HDOP horizontal dilution of position (unitless). If unknown, set to: UINT16_MAX
final
horizAccuracy float
GPS horizontal accuracy
final
ignoreFlags ActuatorConfiguration
Bitmap indicating which GPS input flags fields to ignore. All other fields must be provided.
final
lat ActuatorConfiguration
Latitude (WGS84)
final
lon ActuatorConfiguration
Longitude (WGS84)
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satellitesVisible ActuatorConfiguration
Number of satellites visible.
final
speedAccuracy float
GPS speed accuracy
final
timeUsec ActuatorConfiguration
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final
timeWeek ActuatorConfiguration
GPS week number
final
timeWeekMs ActuatorConfiguration
GPS time (from start of GPS week)
final
vd float
GPS velocity in down direction in earth-fixed NED frame
final
vdop float
GPS VDOP vertical dilution of position (unitless). If unknown, set to: UINT16_MAX
final
ve float
GPS velocity in east direction in earth-fixed NED frame
final
vertAccuracy float
GPS vertical accuracy
final
vn float
GPS velocity in north direction in earth-fixed NED frame
final
yaw ActuatorConfiguration
Yaw of vehicle relative to Earth's North, zero means not available, use 36000 for north
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited