HighLatency class
Message appropriate for high latency connections like Iridium
HIGH_LATENCY
- Implemented types
Constructors
- HighLatency({required uint32_t customMode, required int32_t latitude, required int32_t longitude, required int16_t roll, required int16_t pitch, required uint16_t heading, required int16_t headingSp, required int16_t altitudeAmsl, required int16_t altitudeSp, required uint16_t wpDistance, required MavModeFlag baseMode, required MavLandedState landedState, required int8_t throttle, required uint8_t airspeed, required uint8_t airspeedSp, required uint8_t groundspeed, required int8_t climbRate, required uint8_t gpsNsat, required GpsFixType gpsFixType, required uint8_t batteryRemaining, required int8_t temperature, required int8_t temperatureAir, required uint8_t failsafe, required uint8_t wpNum})
- HighLatency.parse(ByteData data_)
-
factory
Properties
- airspeed → ActuatorConfiguration
-
airspeed
final
- airspeedSp → ActuatorConfiguration
-
airspeed setpoint
final
- altitudeAmsl → ActuatorConfiguration
-
Altitude above mean sea level
final
- altitudeSp → ActuatorConfiguration
-
Altitude setpoint relative to the home position
final
- baseMode → ActuatorConfiguration
-
Bitmap of enabled system modes.
final
- batteryRemaining → ActuatorConfiguration
-
Remaining battery (percentage)
final
- climbRate → ActuatorConfiguration
-
climb rate
final
- customMode → ActuatorConfiguration
-
A bitfield for use for autopilot-specific flags.
final
- failsafe → ActuatorConfiguration
-
failsafe (each bit represents a failsafe where 0=ok, 1=failsafe active (bit0:RC, bit1:batt, bit2:GPS, bit3:GCS, bit4:fence)
final
- gpsFixType → ActuatorConfiguration
-
GPS Fix type.
final
- gpsNsat → ActuatorConfiguration
-
Number of satellites visible. If unknown, set to UINT8_MAX
final
- groundspeed → ActuatorConfiguration
-
groundspeed
final
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- heading → ActuatorConfiguration
-
heading
final
- headingSp → ActuatorConfiguration
-
heading setpoint
final
- landedState → ActuatorConfiguration
-
The landed state. Is set to MAV_LANDED_STATE_UNDEFINED if landed state is unknown.
final
- latitude → ActuatorConfiguration
-
Latitude
final
- longitude → ActuatorConfiguration
-
Longitude
final
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- pitch → ActuatorConfiguration
-
pitch
final
- roll → ActuatorConfiguration
-
roll
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperature → ActuatorConfiguration
-
Autopilot temperature (degrees C)
final
- temperatureAir → ActuatorConfiguration
-
Air temperature (degrees C) from airspeed sensor
final
- throttle → ActuatorConfiguration
-
throttle (percentage)
final
- wpDistance → ActuatorConfiguration
-
distance to target
final
- wpNum → ActuatorConfiguration
-
current waypoint number
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited