HilOpticalFlow class

Simulated optical flow from a flow sensor (e.g. PX4FLOW or optical mouse sensor)

HIL_OPTICAL_FLOW

Implemented types

Constructors

HilOpticalFlow({required uint64_t timeUsec, required uint32_t integrationTimeUs, required float integratedX, required float integratedY, required float integratedXgyro, required float integratedYgyro, required float integratedZgyro, required uint32_t timeDeltaDistanceUs, required float distance, required int16_t temperature, required uint8_t sensorId, required uint8_t quality})
HilOpticalFlow.parse(ByteData data_)
factory

Properties

distance float
Distance to the center of the flow field. Positive value (including zero): distance known. Negative value: Unknown distance.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
integratedX float
Flow in radians around X axis (Sensor RH rotation about the X axis induces a positive flow. Sensor linear motion along the positive Y axis induces a negative flow.)
final
integratedXgyro float
RH rotation around X axis
final
integratedY float
Flow in radians around Y axis (Sensor RH rotation about the Y axis induces a positive flow. Sensor linear motion along the positive X axis induces a positive flow.)
final
integratedYgyro float
RH rotation around Y axis
final
integratedZgyro float
RH rotation around Z axis
final
integrationTimeUs ActuatorConfiguration
Integration time. Divide integrated_x and integrated_y by the integration time to obtain average flow. The integration time also indicates the.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
quality ActuatorConfiguration
Optical flow quality / confidence. 0: no valid flow, 255: maximum quality
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorId ActuatorConfiguration
Sensor ID
final
temperature ActuatorConfiguration
Temperature
final
timeDeltaDistanceUs ActuatorConfiguration
Time since the distance was sampled.
final
timeUsec ActuatorConfiguration
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited