HilStateQuaternion class

Sent from simulation to autopilot, avoids in contrast to HIL_STATE singularities. This packet is useful for high throughput applications such as hardware in the loop simulations.

HIL_STATE_QUATERNION

Implemented types

Constructors

HilStateQuaternion({required uint64_t timeUsec, required List<float> attitudeQuaternion, required float rollspeed, required float pitchspeed, required float yawspeed, required int32_t lat, required int32_t lon, required int32_t alt, required int16_t vx, required int16_t vy, required int16_t vz, required uint16_t indAirspeed, required uint16_t trueAirspeed, required int16_t xacc, required int16_t yacc, required int16_t zacc})
HilStateQuaternion.parse(ByteData data_)
factory

Properties

alt ActuatorConfiguration
Altitude
final
attitudeQuaternion List<float>
Vehicle attitude expressed as normalized quaternion in w, x, y, z order (with 1 0 0 0 being the null-rotation)
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
indAirspeed ActuatorConfiguration
Indicated airspeed
final
lat ActuatorConfiguration
Latitude
final
lon ActuatorConfiguration
Longitude
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
pitchspeed float
Body frame pitch / theta angular speed
final
rollspeed float
Body frame roll / phi angular speed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeUsec ActuatorConfiguration
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final
trueAirspeed ActuatorConfiguration
True airspeed
final
vx ActuatorConfiguration
Ground X Speed (Latitude)
final
vy ActuatorConfiguration
Ground Y Speed (Longitude)
final
vz ActuatorConfiguration
Ground Z Speed (Altitude)
final
xacc ActuatorConfiguration
X acceleration
final
yacc ActuatorConfiguration
Y acceleration
final
yawspeed float
Body frame yaw / psi angular speed
final
zacc ActuatorConfiguration
Z acceleration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited