LinkNodeStatus class

Status generated in each node in the communication chain and injected into MAVLink stream.

LINK_NODE_STATUS

Implemented types

Constructors

LinkNodeStatus({required uint64_t timestamp, required uint32_t txRate, required uint32_t rxRate, required uint32_t messagesSent, required uint32_t messagesReceived, required uint32_t messagesLost, required uint16_t rxParseErr, required uint16_t txOverflows, required uint16_t rxOverflows, required uint8_t txBuf, required uint8_t rxBuf})
LinkNodeStatus.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
messagesLost ActuatorConfiguration
Messages lost (estimated from counting seq)
final
messagesReceived ActuatorConfiguration
Messages received (estimated from counting seq)
final
messagesSent ActuatorConfiguration
Messages sent
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rxBuf ActuatorConfiguration
Remaining free receive buffer space
final
rxOverflows ActuatorConfiguration
Receive buffer overflows. This number wraps around as it reaches UINT16_MAX
final
rxParseErr ActuatorConfiguration
Number of bytes that could not be parsed correctly.
final
rxRate ActuatorConfiguration
Receive rate
final
timestamp ActuatorConfiguration
Timestamp (time since system boot).
final
txBuf ActuatorConfiguration
Remaining free transmit buffer space
final
txOverflows ActuatorConfiguration
Transmit buffer overflows. This number wraps around as it reaches UINT16_MAX
final
txRate ActuatorConfiguration
Transmit rate
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited