LogEntry class

Reply to LOG_REQUEST_LIST

LOG_ENTRY

Implemented types

Constructors

LogEntry({required uint32_t timeUtc, required uint32_t size, required uint16_t id, required uint16_t numLogs, required uint16_t lastLogNum})
LogEntry.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
id ActuatorConfiguration
Log id
final
lastLogNum ActuatorConfiguration
High log number
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
numLogs ActuatorConfiguration
Total number of logs
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ActuatorConfiguration
Size of the log (may be approximate)
final
timeUtc ActuatorConfiguration
UTC timestamp of log since 1970, or 0 if not available
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited