LoggingAck class
An ack for a LOGGING_DATA_ACKED message
LOGGING_ACK
- Implemented types
Constructors
- LoggingAck({required uint16_t sequence, required uint8_t targetSystem, required uint8_t targetComponent})
- LoggingAck.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → ActuatorConfiguration
-
sequence number (must match the one in LOGGING_DATA_ACKED)
final
- targetComponent → ActuatorConfiguration
-
component ID of the target
final
- targetSystem → ActuatorConfiguration
-
system ID of the target
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited