ManualSetpoint class

Setpoint in roll, pitch, yaw and thrust from the operator

MANUAL_SETPOINT

Implemented types

Constructors

ManualSetpoint({required uint32_t timeBootMs, required float roll, required float pitch, required float yaw, required float thrust, required uint8_t modeSwitch, required uint8_t manualOverrideSwitch})
ManualSetpoint.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
manualOverrideSwitch ActuatorConfiguration
Override mode switch position, 0.. 255
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
modeSwitch ActuatorConfiguration
Flight mode switch position, 0.. 255
final
pitch float
Desired pitch rate
final
roll float
Desired roll rate
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thrust float
Collective thrust, normalized to 0 .. 1
final
timeBootMs ActuatorConfiguration
Timestamp (time since system boot).
final
yaw float
Desired yaw rate
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited