MavlinkDialectDevelopment class
- Implemented types
Constructors
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → ActuatorConfiguration
-
no setteroverride
Methods
-
crcExtra(
int messageID) → int -
Returns CRC Extra of messageID. Returns -1 if unsupported messageID.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
int messageID, ByteData data) → MavlinkMessage? -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- mavlinkVersion → const ActuatorConfiguration