MissionAck class

Acknowledgment message during waypoint handling. The type field states if this message is a positive ack (type=0) or if an error happened (type=non-zero).

MISSION_ACK

Implemented types

Constructors

MissionAck({required uint8_t targetSystem, required uint8_t targetComponent, required MavMissionResult type, required MavMissionType missionType, required uint32_t opaqueId})
MissionAck.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
missionType ActuatorConfiguration
Mission type.
final
opaqueId ActuatorConfiguration
Id of new on-vehicle mission, fence, or rally point plan (on upload to vehicle). The id is calculated and returned by a vehicle when a new plan is uploaded by a GCS. The only requirement on the id is that it must change when there is any change to the on-vehicle plan type (there is no requirement that the id be globally unique). 0 on download from the vehicle to the GCS (on download the ID is set in MISSION_COUNT). 0 if plan ids are not supported. The current on-vehicle plan ids are streamed in MISSION_CURRENT, allowing a GCS to determine if any part of the plan has changed and needs to be re-uploaded.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final
type ActuatorConfiguration
Mission result.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited