MissionItem class

Message encoding a mission item. This message is emitted to announce the presence of a mission item and to set a mission item on the system. The mission item can be either in x, y, z meters (type: LOCAL) or x:lat, y:lon, z:altitude. Local frame is Z-down, right handed (NED), global frame is Z-up, right handed (ENU). NaN may be used to indicate an optional/default value (e.g. to use the system's current latitude or yaw rather than a specific value). See also https://mavlink.io/en/services/mission.html.

MISSION_ITEM

Implemented types

Constructors

MissionItem({required float param1, required float param2, required float param3, required float param4, required float x, required float y, required float z, required uint16_t seq, required MavCmd command, required uint8_t targetSystem, required uint8_t targetComponent, required MavFrame frame, required uint8_t current, required uint8_t autocontinue, required MavMissionType missionType})
MissionItem.parse(ByteData data_)
factory

Properties

autocontinue ActuatorConfiguration
Autocontinue to next waypoint. 0: false, 1: true. Set false to pause mission after the item completes.
final
command ActuatorConfiguration
The scheduled action for the waypoint.
final
current ActuatorConfiguration
false:0, true:1
final
frame ActuatorConfiguration
The coordinate system of the waypoint.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
missionType ActuatorConfiguration
Mission type.
final
param1 float
PARAM1, see MAV_CMD enum
final
param2 float
PARAM2, see MAV_CMD enum
final
param3 float
PARAM3, see MAV_CMD enum
final
param4 float
PARAM4, see MAV_CMD enum
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq ActuatorConfiguration
Sequence
final
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final
x float
PARAM5 / local: X coordinate, global: latitude
final
y float
PARAM6 / local: Y coordinate, global: longitude
final
z float
PARAM7 / local: Z coordinate, global: altitude (relative or absolute, depending on frame).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited