MissionItemInt class

Message encoding a mission item. This message is emitted to announce the presence of a mission item and to set a mission item on the system. The mission item can be either in x, y, z meters (type: LOCAL) or x:lat, y:lon, z:altitude. Local frame is Z-down, right handed (NED), global frame is Z-up, right handed (ENU). NaN or INT32_MAX may be used in float/integer params (respectively) to indicate optional/default values (e.g. to use the component's current latitude, yaw rather than a specific value). See also https://mavlink.io/en/services/mission.html.

MISSION_ITEM_INT

Implemented types

Constructors

MissionItemInt({required float param1, required float param2, required float param3, required float param4, required int32_t x, required int32_t y, required float z, required uint16_t seq, required MavCmd command, required uint8_t targetSystem, required uint8_t targetComponent, required MavFrame frame, required uint8_t current, required uint8_t autocontinue, required MavMissionType missionType})
MissionItemInt.parse(ByteData data_)
factory

Properties

autocontinue ActuatorConfiguration
Autocontinue to next waypoint. 0: false, 1: true. Set false to pause mission after the item completes.
final
command ActuatorConfiguration
The scheduled action for the waypoint.
final
current ActuatorConfiguration
false:0, true:1
final
frame ActuatorConfiguration
The coordinate system of the waypoint.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
missionType ActuatorConfiguration
Mission type.
final
param1 float
PARAM1, see MAV_CMD enum
final
param2 float
PARAM2, see MAV_CMD enum
final
param3 float
PARAM3, see MAV_CMD enum
final
param4 float
PARAM4, see MAV_CMD enum
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq ActuatorConfiguration
Waypoint ID (sequence number). Starts at zero. Increases monotonically for each waypoint, no gaps in the sequence (0,1,2,3,4).
final
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final
x ActuatorConfiguration
PARAM5 / local: x position in meters * 1e4, global: latitude in degrees * 10^7
final
y ActuatorConfiguration
PARAM6 / y position: local: x position in meters * 1e4, global: longitude in degrees *10^7
final
z float
PARAM7 / z position: global: altitude in meters (relative or absolute, depending on frame.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited