MissionRequestInt class
Request the information of the mission item with the sequence number seq. The response of the system to this message should be a MISSION_ITEM_INT message. https://mavlink.io/en/services/mission.html
MISSION_REQUEST_INT
- Implemented types
Constructors
- MissionRequestInt({required uint16_t seq, required uint8_t targetSystem, required uint8_t targetComponent, required MavMissionType missionType})
- MissionRequestInt.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- missionType → ActuatorConfiguration
-
Mission type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seq → ActuatorConfiguration
-
Sequence
final
- targetComponent → ActuatorConfiguration
-
Component ID
final
- targetSystem → ActuatorConfiguration
-
System ID
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited