MissionRequestPartialList class

Request a partial list of mission items from the system/component. https://mavlink.io/en/services/mission.html. If start and end index are the same, just send one waypoint.

MISSION_REQUEST_PARTIAL_LIST

Implemented types

Constructors

MissionRequestPartialList({required int16_t startIndex, required int16_t endIndex, required uint8_t targetSystem, required uint8_t targetComponent, required MavMissionType missionType})
MissionRequestPartialList.parse(ByteData data_)
factory

Properties

endIndex ActuatorConfiguration
End index, -1 by default (-1: send list to end). Else a valid index of the list
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
missionType ActuatorConfiguration
Mission type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startIndex ActuatorConfiguration
Start index
final
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited