MountOrientation class

Orientation of a mount

MOUNT_ORIENTATION

Implemented types

Constructors

MountOrientation({required uint32_t timeBootMs, required float roll, required float pitch, required float yaw, required float yawAbsolute})
MountOrientation.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
pitch float
Pitch in global frame (set to NaN for invalid).
final
roll float
Roll in global frame (set to NaN for invalid).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeBootMs ActuatorConfiguration
Timestamp (time since system boot).
final
yaw float
Yaw relative to vehicle (set to NaN for invalid).
final
yawAbsolute float
Yaw in absolute frame relative to Earth's North, north is 0 (set to NaN for invalid).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited