OpenDroneIdLocation class

Data for filling the OpenDroneID Location message. The float data types are 32-bit IEEE 754. The Location message provides the location, altitude, direction and speed of the aircraft.

OPEN_DRONE_ID_LOCATION

Implemented types

Constructors

OpenDroneIdLocation({required int32_t latitude, required int32_t longitude, required float altitudeBarometric, required float altitudeGeodetic, required float height, required float timestamp, required uint16_t direction, required uint16_t speedHorizontal, required int16_t speedVertical, required uint8_t targetSystem, required uint8_t targetComponent, required List<int8_t> idOrMac, required MavOdidStatus status, required MavOdidHeightRef heightReference, required MavOdidHorAcc horizontalAccuracy, required MavOdidVerAcc verticalAccuracy, required MavOdidVerAcc barometerAccuracy, required MavOdidSpeedAcc speedAccuracy, required MavOdidTimeAcc timestampAccuracy})
OpenDroneIdLocation.parse(ByteData data_)
factory

Properties

altitudeBarometric float
The altitude calculated from the barometric pressue. Reference is against 29.92inHg or 1013.2mb. If unknown: -1000 m.
final
altitudeGeodetic float
The geodetic altitude as defined by WGS84. If unknown: -1000 m.
final
barometerAccuracy ActuatorConfiguration
The accuracy of the barometric altitude.
final
direction ActuatorConfiguration
Direction over ground (not heading, but direction of movement) measured clockwise from true North: 0 - 35999 centi-degrees. If unknown: 36100 centi-degrees.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
height float
The current height of the unmanned aircraft above the take-off location or the ground as indicated by height_reference. If unknown: -1000 m.
final
heightReference ActuatorConfiguration
Indicates the reference point for the height field.
final
horizontalAccuracy ActuatorConfiguration
The accuracy of the horizontal position.
final
idOrMac List<int8_t>
Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.
final
latitude ActuatorConfiguration
Current latitude of the unmanned aircraft. If unknown: 0 (both Lat/Lon).
final
longitude ActuatorConfiguration
Current longitude of the unmanned aircraft. If unknown: 0 (both Lat/Lon).
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedAccuracy ActuatorConfiguration
The accuracy of the horizontal and vertical speed.
final
speedHorizontal ActuatorConfiguration
Ground speed. Positive only. If unknown: 25500 cm/s. If speed is larger than 25425 cm/s, use 25425 cm/s.
final
speedVertical ActuatorConfiguration
The vertical speed. Up is positive. If unknown: 6300 cm/s. If speed is larger than 6200 cm/s, use 6200 cm/s. If lower than -6200 cm/s, use -6200 cm/s.
final
status ActuatorConfiguration
Indicates whether the unmanned aircraft is on the ground or in the air.
final
targetComponent ActuatorConfiguration
Component ID (0 for broadcast).
final
targetSystem ActuatorConfiguration
System ID (0 for broadcast).
final
timestamp float
Seconds after the full hour with reference to UTC time. Typically the GPS outputs a time-of-week value in milliseconds. First convert that to UTC and then convert for this field using ((float) (time_week_ms % (60601000))) / 1000. If unknown: 0xFFFF.
final
timestampAccuracy ActuatorConfiguration
The accuracy of the timestamps.
final
verticalAccuracy ActuatorConfiguration
The accuracy of the vertical position.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited