OpenDroneIdMessagePack class

An OpenDroneID message pack is a container for multiple encoded OpenDroneID messages (i.e. not in the format given for the above message descriptions but after encoding into the compressed OpenDroneID byte format). Used e.g. when transmitting on Bluetooth 5.0 Long Range/Extended Advertising or on WiFi Neighbor Aware Networking or on WiFi Beacon.

OPEN_DRONE_ID_MESSAGE_PACK

Implemented types

Constructors

OpenDroneIdMessagePack({required uint8_t targetSystem, required uint8_t targetComponent, required List<int8_t> idOrMac, required uint8_t singleMessageSize, required uint8_t msgPackSize, required List<int8_t> messages})
OpenDroneIdMessagePack.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
idOrMac List<int8_t>
Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
messages List<int8_t>
Concatenation of encoded OpenDroneID messages. Shall be filled with nulls in the unused portion of the field.
final
msgPackSize ActuatorConfiguration
Number of encoded messages in the pack (not the number of bytes). Allowed range is 1 - 9.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleMessageSize ActuatorConfiguration
This field must currently always be equal to 25 (bytes), since all encoded OpenDroneID messages are specified to have this length.
final
targetComponent ActuatorConfiguration
Component ID (0 for broadcast).
final
targetSystem ActuatorConfiguration
System ID (0 for broadcast).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited