OpenDroneIdSystem class

Data for filling the OpenDroneID System message. The System Message contains general system information including the operator location/altitude and possible aircraft group and/or category/class information.

OPEN_DRONE_ID_SYSTEM

Implemented types

Constructors

OpenDroneIdSystem({required int32_t operatorLatitude, required int32_t operatorLongitude, required float areaCeiling, required float areaFloor, required float operatorAltitudeGeo, required uint32_t timestamp, required uint16_t areaCount, required uint16_t areaRadius, required uint8_t targetSystem, required uint8_t targetComponent, required List<int8_t> idOrMac, required MavOdidOperatorLocationType operatorLocationType, required MavOdidClassificationType classificationType, required MavOdidCategoryEu categoryEu, required MavOdidClassEu classEu})
OpenDroneIdSystem.parse(ByteData data_)
factory

Properties

areaCeiling float
Area Operations Ceiling relative to WGS84. If unknown: -1000 m. Used only for swarms/multiple UA.
final
areaCount ActuatorConfiguration
Number of aircraft in the area, group or formation (default 1). Used only for swarms/multiple UA.
final
areaFloor float
Area Operations Floor relative to WGS84. If unknown: -1000 m. Used only for swarms/multiple UA.
final
areaRadius ActuatorConfiguration
Radius of the cylindrical area of the group or formation (default 0). Used only for swarms/multiple UA.
final
categoryEu ActuatorConfiguration
When classification_type is MAV_ODID_CLASSIFICATION_TYPE_EU, specifies the category of the UA.
final
classEu ActuatorConfiguration
When classification_type is MAV_ODID_CLASSIFICATION_TYPE_EU, specifies the class of the UA.
final
classificationType ActuatorConfiguration
Specifies the classification type of the UA.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
idOrMac List<int8_t>
Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
operatorAltitudeGeo float
Geodetic altitude of the operator relative to WGS84. If unknown: -1000 m.
final
operatorLatitude ActuatorConfiguration
Latitude of the operator. If unknown: 0 (both Lat/Lon).
final
operatorLocationType ActuatorConfiguration
Specifies the operator location type.
final
operatorLongitude ActuatorConfiguration
Longitude of the operator. If unknown: 0 (both Lat/Lon).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID (0 for broadcast).
final
targetSystem ActuatorConfiguration
System ID (0 for broadcast).
final
timestamp ActuatorConfiguration
32 bit Unix Timestamp in seconds since 00:00:00 01/01/2019.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited