OpenDroneIdSystemUpdate class

Update the data in the OPEN_DRONE_ID_SYSTEM message with new location information. This can be sent to update the location information for the operator when no other information in the SYSTEM message has changed. This message allows for efficient operation on radio links which have limited uplink bandwidth while meeting requirements for update frequency of the operator location.

OPEN_DRONE_ID_SYSTEM_UPDATE

Implemented types

Constructors

OpenDroneIdSystemUpdate({required int32_t operatorLatitude, required int32_t operatorLongitude, required float operatorAltitudeGeo, required uint32_t timestamp, required uint8_t targetSystem, required uint8_t targetComponent})
OpenDroneIdSystemUpdate.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
operatorAltitudeGeo float
Geodetic altitude of the operator relative to WGS84. If unknown: -1000 m.
final
operatorLatitude ActuatorConfiguration
Latitude of the operator. If unknown: 0 (both Lat/Lon).
final
operatorLongitude ActuatorConfiguration
Longitude of the operator. If unknown: 0 (both Lat/Lon).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID (0 for broadcast).
final
targetSystem ActuatorConfiguration
System ID (0 for broadcast).
final
timestamp ActuatorConfiguration
32 bit Unix Timestamp in seconds since 00:00:00 01/01/2019.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited