ParamValue class

Emit the value of a onboard parameter. The inclusion of param_count and param_index in the message allows the recipient to keep track of received parameters and allows him to re-request missing parameters after a loss or timeout. The parameter microservice is documented at https://mavlink.io/en/services/parameter.html

PARAM_VALUE

Implemented types

Constructors

ParamValue({required float paramValue, required uint16_t paramCount, required uint16_t paramIndex, required List<int8_t> paramId, required MavParamType paramType})
ParamValue.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
paramCount ActuatorConfiguration
Total number of onboard parameters
final
paramId List<int8_t>
Onboard parameter id, terminated by NULL if the length is less than 16 human-readable chars and WITHOUT null termination (NULL) byte if the length is exactly 16 chars - applications have to provide 16+1 bytes storage if the ID is stored as string
final
paramIndex ActuatorConfiguration
Index of this onboard parameter
final
paramType ActuatorConfiguration
Onboard parameter type.
final
paramValue float
Onboard parameter value
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited