RadioStatus class

Status generated by radio and injected into MAVLink stream.

RADIO_STATUS

Implemented types

Constructors

RadioStatus({required uint16_t rxerrors, required uint16_t fixed, required uint8_t rssi, required uint8_t remrssi, required uint8_t txbuf, required uint8_t noise, required uint8_t remnoise})
RadioStatus.parse(ByteData data_)
factory

Properties

fixed ActuatorConfiguration
Count of error corrected radio packets (since boot).
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
noise ActuatorConfiguration
Local background noise level. These are device dependent RSSI values (scale as approx 2x dB on SiK radios). Values: 0-254, UINT8_MAX: invalid/unknown.
final
remnoise ActuatorConfiguration
Remote background noise level. These are device dependent RSSI values (scale as approx 2x dB on SiK radios). Values: 0-254, UINT8_MAX: invalid/unknown.
final
remrssi ActuatorConfiguration
Remote (message receiver) signal strength indication in device-dependent units/scale. Values: 0-254, UINT8_MAX: invalid/unknown.
final
rssi ActuatorConfiguration
Local (message sender) received signal strength indication in device-dependent units/scale. Values: 0-254, UINT8_MAX: invalid/unknown.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rxerrors ActuatorConfiguration
Count of radio packet receive errors (since boot).
final
txbuf ActuatorConfiguration
Remaining free transmitter buffer space.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited