RawImu class

The RAW IMU readings for a 9DOF sensor, which is identified by the id (default IMU1). This message should always contain the true raw values without any scaling to allow data capture and system debugging.

RAW_IMU

Implemented types

Constructors

RawImu({required uint64_t timeUsec, required int16_t xacc, required int16_t yacc, required int16_t zacc, required int16_t xgyro, required int16_t ygyro, required int16_t zgyro, required int16_t xmag, required int16_t ymag, required int16_t zmag, required uint8_t id, required int16_t temperature})
RawImu.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
id ActuatorConfiguration
Id. Ids are numbered from 0 and map to IMUs numbered from 1 (e.g. IMU1 will have a message with id=0)
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature ActuatorConfiguration
Temperature, 0: IMU does not provide temperature values. If the IMU is at 0C it must send 1 (0.01C).
final
timeUsec ActuatorConfiguration
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final
xacc ActuatorConfiguration
X acceleration (raw)
final
xgyro ActuatorConfiguration
Angular speed around X axis (raw)
final
xmag ActuatorConfiguration
X Magnetic field (raw)
final
yacc ActuatorConfiguration
Y acceleration (raw)
final
ygyro ActuatorConfiguration
Angular speed around Y axis (raw)
final
ymag ActuatorConfiguration
Y Magnetic field (raw)
final
zacc ActuatorConfiguration
Z acceleration (raw)
final
zgyro ActuatorConfiguration
Angular speed around Z axis (raw)
final
zmag ActuatorConfiguration
Z Magnetic field (raw)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited