RawPressure class

The RAW pressure readings for the typical setup of one absolute pressure and one differential pressure sensor. The sensor values should be the raw, UNSCALED ADC values.

RAW_PRESSURE

Implemented types

Constructors

RawPressure({required uint64_t timeUsec, required int16_t pressAbs, required int16_t pressDiff1, required int16_t pressDiff2, required int16_t temperature})
RawPressure.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
pressAbs ActuatorConfiguration
Absolute pressure (raw)
final
pressDiff1 ActuatorConfiguration
Differential pressure 1 (raw, 0 if nonexistent)
final
pressDiff2 ActuatorConfiguration
Differential pressure 2 (raw, 0 if nonexistent)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature ActuatorConfiguration
Raw Temperature measurement (raw)
final
timeUsec ActuatorConfiguration
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited