RequestEvent class

Request one or more events to be (re-)sent. If first_sequence==last_sequence, only a single event is requested. Note that first_sequence can be larger than last_sequence (because the sequence number can wrap). Each sequence will trigger an EVENT or EVENT_ERROR response.

REQUEST_EVENT

Implemented types

Constructors

RequestEvent({required uint16_t firstSequence, required uint16_t lastSequence, required uint8_t targetSystem, required uint8_t targetComponent})
RequestEvent.parse(ByteData data_)
factory

Properties

firstSequence ActuatorConfiguration
First sequence number of the requested event.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
lastSequence ActuatorConfiguration
Last sequence number of the requested event.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited