ScaledImu2 class

The RAW IMU readings for secondary 9DOF sensor setup. This message should contain the scaled values to the described units

SCALED_IMU2

Implemented types

Constructors

ScaledImu2({required uint32_t timeBootMs, required int16_t xacc, required int16_t yacc, required int16_t zacc, required int16_t xgyro, required int16_t ygyro, required int16_t zgyro, required int16_t xmag, required int16_t ymag, required int16_t zmag, required int16_t temperature})
ScaledImu2.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature ActuatorConfiguration
Temperature, 0: IMU does not provide temperature values. If the IMU is at 0C it must send 1 (0.01C).
final
timeBootMs ActuatorConfiguration
Timestamp (time since system boot).
final
xacc ActuatorConfiguration
X acceleration
final
xgyro ActuatorConfiguration
Angular speed around X axis
final
xmag ActuatorConfiguration
X Magnetic field
final
yacc ActuatorConfiguration
Y acceleration
final
ygyro ActuatorConfiguration
Angular speed around Y axis
final
ymag ActuatorConfiguration
Y Magnetic field
final
zacc ActuatorConfiguration
Z acceleration
final
zgyro ActuatorConfiguration
Angular speed around Z axis
final
zmag ActuatorConfiguration
Z Magnetic field
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited