SetGpsGlobalOrigin class

Sets the GPS coordinates of the vehicle local origin (0,0,0) position. Vehicle should emit GPS_GLOBAL_ORIGIN irrespective of whether the origin is changed. This enables transform between the local coordinate frame and the global (GPS) coordinate frame, which may be necessary when (for example) indoor and outdoor settings are connected and the MAV should move from in- to outdoor.

SET_GPS_GLOBAL_ORIGIN

Implemented types

Constructors

SetGpsGlobalOrigin({required int32_t latitude, required int32_t longitude, required int32_t altitude, required uint8_t targetSystem, required uint64_t timeUsec})
SetGpsGlobalOrigin.parse(ByteData data_)
factory

Properties

altitude ActuatorConfiguration
Altitude (MSL). Positive for up.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
latitude ActuatorConfiguration
Latitude (WGS84)
final
longitude ActuatorConfiguration
Longitude (WGS84)
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSystem ActuatorConfiguration
System ID
final
timeUsec ActuatorConfiguration
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited