SetMode class

Set the system mode, as defined by enum MAV_MODE. There is no target component id as the mode is by definition for the overall aircraft, not only for one component.

SET_MODE

Implemented types

Constructors

SetMode({required uint32_t customMode, required uint8_t targetSystem, required MavMode baseMode})
SetMode.parse(ByteData data_)
factory

Properties

baseMode ActuatorConfiguration
The new base mode.
final
customMode ActuatorConfiguration
The new autopilot-specific mode. This field can be ignored by an autopilot.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSystem ActuatorConfiguration
The system setting the mode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited