SetVelocityLimits class

Set temporary maximum limits for horizontal speed, vertical speed and yaw rate. The consumer must stream the current limits in VELOCITY_LIMITS at 1 Hz or more (when limits are being set). The consumer should latch the limits until a new limit is received or the mode is changed.

SET_VELOCITY_LIMITS

Implemented types

Constructors

SetVelocityLimits({required float horizontalSpeedLimit, required float verticalSpeedLimit, required float yawRateLimit, required uint8_t targetSystem, required uint8_t targetComponent})
SetVelocityLimits.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
horizontalSpeedLimit float
Limit for horizontal movement in MAV_FRAME_LOCAL_NED. NaN: Field not used (ignore)
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID (0 for broadcast).
final
targetSystem ActuatorConfiguration
System ID (0 for broadcast).
final
verticalSpeedLimit float
Limit for vertical movement in MAV_FRAME_LOCAL_NED. NaN: Field not used (ignore)
final
yawRateLimit float
Limit for vehicle turn rate around its yaw axis. NaN: Field not used (ignore)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited