TargetAbsolute class

Current motion information from sensors on a target

TARGET_ABSOLUTE

Implemented types

Constructors

TargetAbsolute({required uint64_t timestamp, required int32_t lat, required int32_t lon, required float alt, required List<float> vel, required List<float> acc, required List<float> qTarget, required List<float> rates, required List<float> positionStd, required List<float> velStd, required List<float> accStd, required uint8_t id, required TargetAbsoluteSensorCapabilityFlags sensorCapabilities})
TargetAbsolute.parse(ByteData data_)
factory

Properties

acc List<float>
Linear target's acceleration in its body frame
final
accStd List<float>
Standard deviation of the target's acceleration in its body frame
final
alt float
Target's altitude (AMSL)
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
id ActuatorConfiguration
The ID of the target if multiple targets are present
final
lat ActuatorConfiguration
Target's latitude (WGS84)
final
lon ActuatorConfiguration
Target's longitude (WGS84)
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
positionStd List<float>
Standard deviation of horizontal (eph) and vertical (epv) position errors
final
qTarget List<float>
Quaternion of the target's orientation from its body frame to the vehicle's NED frame.
final
rates List<float>
Target's roll, pitch and yaw rates
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorCapabilities ActuatorConfiguration
Bitmap to indicate the sensor's reporting capabilities
final
timestamp ActuatorConfiguration
Timestamp (UNIX epoch time).
final
vel List<float>
Target's velocity in its body frame
final
velStd List<float>
Standard deviation of the target's velocity in its body frame
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited