TargetRelative class

The location of a target measured by MAV's onboard sensors.

TARGET_RELATIVE

Implemented types

Constructors

TargetRelative({required uint64_t timestamp, required float x, required float y, required float z, required List<float> posStd, required float yawStd, required List<float> qTarget, required List<float> qSensor, required uint8_t id, required TargetObsFrame frame, required LandingTargetType type})
TargetRelative.parse(ByteData data_)
factory

Properties

frame ActuatorConfiguration
Coordinate frame used for following fields.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
id ActuatorConfiguration
The ID of the target if multiple targets are present
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
posStd List<float>
Standard deviation of the target's position in TARGET_OBS_FRAME
final
qSensor List<float>
Quaternion of the sensor's orientation from TARGET_OBS_FRAME to vehicle-carried NED. (Ignored if set to (0,0,0,0)) (w, x, y, z order, zero-rotation is 1, 0, 0, 0)
final
qTarget List<float>
Quaternion of the target's orientation from the target's frame to the TARGET_OBS_FRAME (w, x, y, z order, zero-rotation is 1, 0, 0, 0)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp ActuatorConfiguration
Timestamp (UNIX epoch time)
final
type ActuatorConfiguration
Type of target
final
x float
X Position of the target in TARGET_OBS_FRAME
final
y float
Y Position of the target in TARGET_OBS_FRAME
final
yawStd float
Standard deviation of the target's orientation in TARGET_OBS_FRAME
final
z float
Z Position of the target in TARGET_OBS_FRAME
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited