TerrainData class

Terrain data sent from GCS. The lat/lon and grid_spacing must be the same as a lat/lon from a TERRAIN_REQUEST. See terrain protocol docs: https://mavlink.io/en/services/terrain.html

TERRAIN_DATA

Implemented types

Constructors

TerrainData({required int32_t lat, required int32_t lon, required uint16_t gridSpacing, required List<int8_t> data, required uint8_t gridbit})
TerrainData.parse(ByteData data_)
factory

Properties

data List<int8_t>
Terrain data MSL
final
gridbit ActuatorConfiguration
bit within the terrain request mask
final
gridSpacing ActuatorConfiguration
Grid spacing
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
lat ActuatorConfiguration
Latitude of SW corner of first grid
final
lon ActuatorConfiguration
Longitude of SW corner of first grid
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited