TerrainReport class

Streamed from drone to report progress of terrain map download (initiated by TERRAIN_REQUEST), or sent as a response to a TERRAIN_CHECK request. See terrain protocol docs: https://mavlink.io/en/services/terrain.html

TERRAIN_REPORT

Implemented types

Constructors

TerrainReport({required int32_t lat, required int32_t lon, required float terrainHeight, required float currentHeight, required uint16_t spacing, required uint16_t pending, required uint16_t loaded})
TerrainReport.parse(ByteData data_)
factory

Properties

currentHeight float
Current vehicle height above lat/lon terrain height
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
lat ActuatorConfiguration
Latitude
final
loaded ActuatorConfiguration
Number of 4x4 terrain blocks in memory
final
lon ActuatorConfiguration
Longitude
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
pending ActuatorConfiguration
Number of 4x4 terrain blocks waiting to be received or read from disk
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing ActuatorConfiguration
grid spacing (zero if terrain at this location unavailable)
final
terrainHeight float
Terrain height MSL
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited