TerrainRequest class

Request for terrain data and terrain status. See terrain protocol docs: https://mavlink.io/en/services/terrain.html

TERRAIN_REQUEST

Implemented types

Constructors

TerrainRequest({required uint64_t mask, required int32_t lat, required int32_t lon, required uint16_t gridSpacing})
TerrainRequest.parse(ByteData data_)
factory

Properties

gridSpacing ActuatorConfiguration
Grid spacing
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
lat ActuatorConfiguration
Latitude of SW corner of first grid
final
lon ActuatorConfiguration
Longitude of SW corner of first grid
final
mask ActuatorConfiguration
Bitmask of requested 4x4 grids (row major 8x7 array of grids, 56 bits)
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited