TimeEstimateToTarget class

Time/duration estimates for various events and actions given the current vehicle state and position.

TIME_ESTIMATE_TO_TARGET

Implemented types

Constructors

TimeEstimateToTarget({required int32_t safeReturn, required int32_t land, required int32_t missionNextItem, required int32_t missionEnd, required int32_t commandedAction})
TimeEstimateToTarget.parse(ByteData data_)
factory

Properties

commandedAction ActuatorConfiguration
Estimated time for completing the current commanded action (i.e. Go To, Takeoff, Land, etc.). -1 means no action active and/or no estimate available.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
land ActuatorConfiguration
Estimated time for vehicle to complete the LAND action from its current position. -1 indicates that the vehicle is landed, or that no time estimate available.
final
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
missionEnd ActuatorConfiguration
Estimated time for completing the current mission. -1 means no mission active and/or no estimate available.
final
missionNextItem ActuatorConfiguration
Estimated time for reaching/completing the currently active mission item. -1 means no time estimate available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeReturn ActuatorConfiguration
Estimated time to complete the vehicle's configured "safe return" action from its current position (e.g. RTL, Smart RTL, etc.). -1 indicates that the vehicle is landed, or that no time estimate available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited