WifiNetworkInfo class

Detected WiFi network status information. This message is sent per each WiFi network detected in range with known SSID and general status parameters.

WIFI_NETWORK_INFO

Implemented types

Constructors

WifiNetworkInfo({required uint16_t dataRate, required List<int8_t> ssid, required uint8_t channelId, required uint8_t signalQuality, required WifiNetworkSecurity security})
WifiNetworkInfo.parse(ByteData data_)
factory

Properties

channelId ActuatorConfiguration
WiFi network operating channel ID. Set to 0 if unknown or unidentified.
final
dataRate ActuatorConfiguration
WiFi network data rate. Set to UINT16_MAX if data_rate information is not supplied.
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
security ActuatorConfiguration
WiFi network security type.
final
signalQuality ActuatorConfiguration
WiFi network signal quality.
final
ssid List<int8_t>
Name of Wi-Fi network (SSID).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited