Altitudes class
The altitude measured by sensors and IMU
ALTITUDES
- Implemented types
Constructors
Properties
- altBarometric → ActuatorConfiguration
-
barometeric altitude above ground in meters, expressed as * 1000 (millimeters)
final
- altExtra → ActuatorConfiguration
-
Extra altitude above ground in meters, expressed as * 1000 (millimeters)
final
- altGps → ActuatorConfiguration
-
GPS altitude (MSL) in meters, expressed as * 1000 (millimeters)
final
- altImu → ActuatorConfiguration
-
IMU altitude above ground in meters, expressed as * 1000 (millimeters)
final
- altOpticalFlow → ActuatorConfiguration
-
Optical flow altitude above ground in meters, expressed as * 1000 (millimeters)
final
- altRangeFinder → ActuatorConfiguration
-
Rangefinder Altitude above ground in meters, expressed as * 1000 (millimeters)
final
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeBootMs → ActuatorConfiguration
-
Timestamp (milliseconds since system boot)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited