FlexifunctionBufferFunction class

Flexifunction type and parameters for component at function index from buffer

FLEXIFUNCTION_BUFFER_FUNCTION

Implemented types

Constructors

FlexifunctionBufferFunction({required uint16_t funcIndex, required uint16_t funcCount, required uint16_t dataAddress, required uint16_t dataSize, required uint8_t targetSystem, required uint8_t targetComponent, required List<int8_t> data})
FlexifunctionBufferFunction.parse(ByteData data_)
factory

Properties

data List<int8_t>
Settings data
final
dataAddress ActuatorConfiguration
Address in the flexifunction data, Set to 0xFFFF to use address in target memory
final
dataSize ActuatorConfiguration
Size of the
final
funcCount ActuatorConfiguration
Total count of functions
final
funcIndex ActuatorConfiguration
Function index
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited