FlexifunctionBufferFunctionAck class

Flexifunction type and parameters for component at function index from buffer

FLEXIFUNCTION_BUFFER_FUNCTION_ACK

Implemented types

Constructors

FlexifunctionBufferFunctionAck({required uint16_t funcIndex, required uint16_t result, required uint8_t targetSystem, required uint8_t targetComponent})
FlexifunctionBufferFunctionAck.parse(ByteData data_)
factory

Properties

funcIndex ActuatorConfiguration
Function index
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
result ActuatorConfiguration
result of acknowledge, 0=fail, 1=good
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent ActuatorConfiguration
Component ID
final
targetSystem ActuatorConfiguration
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited