FlexifunctionCommandAck class

Acknowldge success or failure of a flexifunction command

FLEXIFUNCTION_COMMAND_ACK

Implemented types

Constructors

FlexifunctionCommandAck({required uint16_t commandType, required uint16_t result})
FlexifunctionCommandAck.parse(ByteData data_)
factory

Properties

commandType ActuatorConfiguration
Command acknowledged
final
hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
result ActuatorConfiguration
result of acknowledge
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited