dialects/standard
library
Classes
-
Heartbeat
-
The heartbeat message shows that a system or component is present and responding. The type and autopilot fields (along with the message component id), allow the receiving system to treat further messages from this system appropriately (e.g. by laying out the user interface based on the autopilot). This microservice is documented at https://mavlink.io/en/services/heartbeat.html
-
MavlinkDialectStandard
-
-
ProtocolVersion
-
Version and capability of protocol version. This message can be requested with MAV_CMD_REQUEST_MESSAGE and is used as part of the handshaking to establish which MAVLink version should be used on the network. Every node should respond to a request for PROTOCOL_VERSION to enable the handshaking. Library implementers should consider adding this into the default decoding state machine to allow the protocol core to respond directly.
Constants
-
mavAutopilotAerob
→ const MavAutopilot
-
Aerob -- http://aerob.ru
-
mavAutopilotAirrails
→ const MavAutopilot
-
AirRails - http://uaventure.com
-
mavAutopilotArdupilotmega
→ const MavAutopilot
-
ArduPilot - Plane/Copter/Rover/Sub/Tracker, https://ardupilot.org
-
mavAutopilotArmazila
→ const MavAutopilot
-
Armazila -- http://armazila.com
-
mavAutopilotAsluav
→ const MavAutopilot
-
ASLUAV autopilot -- http://www.asl.ethz.ch
-
mavAutopilotAutoquad
→ const MavAutopilot
-
AutoQuad -- http://autoquad.org
-
mavAutopilotFp
→ const MavAutopilot
-
FlexiPilot
-
mavAutopilotGeneric
→ const MavAutopilot
-
Generic autopilot, full support for everything
-
mavAutopilotGenericMissionFull
→ const MavAutopilot
-
Generic autopilot supporting the full mission command set
-
mavAutopilotGenericWaypointsAndSimpleNavigationOnly
→ const MavAutopilot
-
Generic autopilot supporting waypoints and other simple navigation commands
-
mavAutopilotGenericWaypointsOnly
→ const MavAutopilot
-
Generic autopilot only supporting simple waypoints
-
mavAutopilotInvalid
→ const MavAutopilot
-
No valid autopilot, e.g. a GCS or other MAVLink component
-
mavAutopilotOpenpilot
→ const MavAutopilot
-
OpenPilot, http://openpilot.org
-
mavAutopilotPpz
→ const MavAutopilot
-
PPZ UAV - http://nongnu.org/paparazzi
-
mavAutopilotPx4
→ const MavAutopilot
-
PX4 Autopilot - http://px4.io/
-
mavAutopilotReflex
→ const MavAutopilot
-
Fusion Reflex - https://fusion.engineering
-
mavAutopilotReserved
→ const MavAutopilot
-
Reserved for future use.
-
mavAutopilotSlugs
→ const MavAutopilot
-
SLUGS autopilot, http://slugsuav.soe.ucsc.edu
-
mavAutopilotSmaccmpilot
→ const MavAutopilot
-
SMACCMPilot - http://smaccmpilot.org
-
mavAutopilotSmartap
→ const MavAutopilot
-
SmartAP Autopilot - http://sky-drones.com
-
mavAutopilotUdb
→ const MavAutopilot
-
UAV Dev Board
-
mavCompIdAdsb
→ const MavAutopilot
-
Automatic Dependent Surveillance-Broadcast (ADS-B) component.
-
mavCompIdAll
→ const MavAutopilot
-
Target id (target_component) used to broadcast messages to all components of the receiving system. Components should attempt to process messages with this component ID and forward to components on any other interfaces. Note: This is not a valid source component id for a message.
-
mavCompIdAutopilot1
→ const MavAutopilot
-
System flight controller component ("autopilot"). Only one autopilot is expected in a particular system.
-
mavCompIdBattery
→ const MavAutopilot
-
Battery #1.
-
mavCompIdBattery2
→ const MavAutopilot
-
Battery #2.
-
mavCompIdCamera
→ const MavAutopilot
-
Camera #1.
-
mavCompIdCamera2
→ const MavAutopilot
-
Camera #2.
-
mavCompIdCamera3
→ const MavAutopilot
-
Camera #3.
-
mavCompIdCamera4
→ const MavAutopilot
-
Camera #4.
-
mavCompIdCamera5
→ const MavAutopilot
-
Camera #5.
-
mavCompIdCamera6
→ const MavAutopilot
-
Camera #6.
-
mavCompIdFlarm
→ const MavAutopilot
-
FLARM collision alert component.
-
mavCompIdGimbal
→ const MavAutopilot
-
Gimbal #1.
-
mavCompIdGimbal2
→ const MavAutopilot
-
Gimbal #2.
-
mavCompIdGimbal3
→ const MavAutopilot
-
Gimbal #3.
-
mavCompIdGimbal4
→ const MavAutopilot
-
Gimbal #4
-
mavCompIdGimbal5
→ const MavAutopilot
-
Gimbal #5.
-
mavCompIdGimbal6
→ const MavAutopilot
-
Gimbal #6.
-
mavCompIdGps
→ const MavAutopilot
-
GPS #1.
-
mavCompIdGps2
→ const MavAutopilot
-
GPS #2.
-
mavCompIdImu
→ const MavAutopilot
-
Inertial Measurement Unit (IMU) #1.
-
mavCompIdImu2
→ const MavAutopilot
-
Inertial Measurement Unit (IMU) #2.
-
mavCompIdImu3
→ const MavAutopilot
-
Inertial Measurement Unit (IMU) #3.
-
mavCompIdLog
→ const MavAutopilot
-
Logging component.
-
mavCompIdMavcan
→ const MavAutopilot
-
CAN over MAVLink client.
-
mavCompIdMissionplanner
→ const MavAutopilot
-
Component that can generate/supply a mission flight plan (e.g. GCS or developer API).
-
mavCompIdObstacleAvoidance
→ const MavAutopilot
-
Component that plans a collision free path between two points.
-
mavCompIdOdidTxrx1
→ const MavAutopilot
-
Open Drone ID transmitter/receiver (Bluetooth/WiFi/Internet).
-
mavCompIdOdidTxrx2
→ const MavAutopilot
-
Open Drone ID transmitter/receiver (Bluetooth/WiFi/Internet).
-
mavCompIdOdidTxrx3
→ const MavAutopilot
-
Open Drone ID transmitter/receiver (Bluetooth/WiFi/Internet).
-
mavCompIdOnboardComputer
→ const MavAutopilot
-
Component that lives on the onboard computer (companion computer) and has some generic functionalities, such as settings system parameters and monitoring the status of some processes that don't directly speak mavlink and so on.
-
mavCompIdOnboardComputer2
→ const MavAutopilot
-
Component that lives on the onboard computer (companion computer) and has some generic functionalities, such as settings system parameters and monitoring the status of some processes that don't directly speak mavlink and so on.
-
mavCompIdOnboardComputer3
→ const MavAutopilot
-
Component that lives on the onboard computer (companion computer) and has some generic functionalities, such as settings system parameters and monitoring the status of some processes that don't directly speak mavlink and so on.
-
mavCompIdOnboardComputer4
→ const MavAutopilot
-
Component that lives on the onboard computer (companion computer) and has some generic functionalities, such as settings system parameters and monitoring the status of some processes that don't directly speak mavlink and so on.
-
mavCompIdOsd
→ const MavAutopilot
-
On Screen Display (OSD) devices for video links.
-
mavCompIdPairingManager
→ const MavAutopilot
-
Component that manages pairing of vehicle and GCS.
-
mavCompIdParachute
→ const MavAutopilot
-
Parachute component.
-
mavCompIdPathplanner
→ const MavAutopilot
-
Component that finds an optimal path between points based on a certain constraint (e.g. minimum snap, shortest path, cost, etc.).
-
mavCompIdPeripheral
→ const MavAutopilot
-
Generic autopilot peripheral component ID. Meant for devices that do not implement the parameter microservice.
-
mavCompIdQx1Gimbal
→ const MavAutopilot
-
Gimbal ID for QX1.
-
mavCompIdServo1
→ const MavAutopilot
-
Servo #1.
-
mavCompIdServo10
→ const MavAutopilot
-
Servo #10.
-
mavCompIdServo11
→ const MavAutopilot
-
Servo #11.
-
mavCompIdServo12
→ const MavAutopilot
-
Servo #12.
-
mavCompIdServo13
→ const MavAutopilot
-
Servo #13.
-
mavCompIdServo14
→ const MavAutopilot
-
Servo #14.
-
mavCompIdServo2
→ const MavAutopilot
-
Servo #2.
-
mavCompIdServo3
→ const MavAutopilot
-
Servo #3.
-
mavCompIdServo4
→ const MavAutopilot
-
Servo #4.
-
mavCompIdServo5
→ const MavAutopilot
-
Servo #5.
-
mavCompIdServo6
→ const MavAutopilot
-
Servo #6.
-
mavCompIdServo7
→ const MavAutopilot
-
Servo #7.
-
mavCompIdServo8
→ const MavAutopilot
-
Servo #8.
-
mavCompIdServo9
→ const MavAutopilot
-
Servo #9.
-
mavCompIdSystemControl
→ const MavAutopilot
-
Deprecated, don't use. Component for handling system messages (e.g. to ARM, takeoff, etc.).
-
mavCompIdTelemetryRadio
→ const MavAutopilot
-
Telemetry radio (e.g. SiK radio, or other component that emits RADIO_STATUS messages).
-
mavCompIdTunnelNode
→ const MavAutopilot
-
Component handling TUNNEL messages (e.g. vendor specific GUI of a component).
-
mavCompIdUartBridge
→ const MavAutopilot
-
Component to bridge to UART (i.e. from UDP).
-
mavCompIdUdpBridge
→ const MavAutopilot
-
Component to bridge MAVLink to UDP (i.e. from a UART).
-
mavCompIdUser1
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser10
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser11
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser12
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser13
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser14
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser15
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser16
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser17
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser18
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser19
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser2
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser20
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser21
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser22
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser23
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser24
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser25
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser26
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser27
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser28
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser29
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser3
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser30
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser31
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser32
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser33
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser34
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser35
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser36
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser37
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser38
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser39
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser4
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser40
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser41
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser42
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser43
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser45
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser46
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser47
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser48
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser49
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser5
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser50
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser51
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser52
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser53
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser54
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser55
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser56
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser57
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser58
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser59
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser6
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser60
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser61
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser62
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser63
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser64
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser65
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser66
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser67
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser68
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser69
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser7
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser70
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser71
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser72
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser73
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser74
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser75
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser8
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdUser9
→ const MavAutopilot
-
Id for a component on privately managed MAVLink network. Can be used for any purpose but may not be published by components outside of the private network.
-
mavCompIdVisualInertialOdometry
→ const MavAutopilot
-
Component that provides position estimates using VIO techniques.
-
mavCompIdWinch
→ const MavAutopilot
-
Winch component.
-
mavModeFlagAutoEnabled
→ const MavAutopilot
-
0b00000100 autonomous mode enabled, system finds its own goal positions. Guided flag can be set or not, depends on the actual implementation.
-
mavModeFlagCustomModeEnabled
→ const MavAutopilot
-
0b00000001 Reserved for future use.
-
mavModeFlagDecodePositionAuto
→ const MavAutopilot
-
Sixth bit: 00000100
-
mavModeFlagDecodePositionCustomMode
→ const MavAutopilot
-
Eighth bit: 00000001
-
mavModeFlagDecodePositionGuided
→ const MavAutopilot
-
Fifth bit: 00001000
-
mavModeFlagDecodePositionHil
→ const MavAutopilot
-
Third bit: 00100000
-
mavModeFlagDecodePositionManual
→ const MavAutopilot
-
Second bit: 01000000
-
mavModeFlagDecodePositionSafety
→ const MavAutopilot
-
First bit: 10000000
-
mavModeFlagDecodePositionStabilize
→ const MavAutopilot
-
Fourth bit: 00010000
-
mavModeFlagDecodePositionTest
→ const MavAutopilot
-
Seventh bit: 00000010
-
mavModeFlagGuidedEnabled
→ const MavAutopilot
-
0b00001000 guided mode enabled, system flies waypoints / mission items.
-
mavModeFlagHilEnabled
→ const MavAutopilot
-
0b00100000 hardware in the loop simulation. All motors / actuators are blocked, but internal software is full operational.
-
mavModeFlagManualInputEnabled
→ const MavAutopilot
-
0b01000000 remote control input is enabled.
-
mavModeFlagSafetyArmed
→ const MavAutopilot
-
0b10000000 MAV safety set to armed. Motors are enabled / running / can start. Ready to fly. Additional note: this flag is to be ignore when sent in the command MAV_CMD_DO_SET_MODE and MAV_CMD_COMPONENT_ARM_DISARM shall be used instead. The flag can still be used to report the armed state.
-
mavModeFlagStabilizeEnabled
→ const MavAutopilot
-
0b00010000 system stabilizes electronically its attitude (and optionally position). It needs however further control inputs to move around.
-
mavModeFlagTestEnabled
→ const MavAutopilot
-
0b00000010 system has a test mode enabled. This flag is intended for temporary system tests and should not be used for stable implementations.
-
mavStateActive
→ const MavAutopilot
-
System is active and might be already airborne. Motors are engaged.
-
mavStateBoot
→ const MavAutopilot
-
System is booting up.
-
mavStateCalibrating
→ const MavAutopilot
-
System is calibrating and not flight-ready.
-
mavStateCritical
→ const MavAutopilot
-
System is in a non-normal flight mode (failsafe). It can however still navigate.
-
mavStateEmergency
→ const MavAutopilot
-
System is in a non-normal flight mode (failsafe). It lost control over parts or over the whole airframe. It is in mayday and going down.
-
mavStateFlightTermination
→ const MavAutopilot
-
System is terminating itself (failsafe or commanded).
-
mavStatePoweroff
→ const MavAutopilot
-
System just initialized its power-down sequence, will shut down now.
-
mavStateStandby
→ const MavAutopilot
-
System is grounded and on standby. It can be launched any time.
-
mavStateUninit
→ const MavAutopilot
-
Uninitialized system, state is unknown.
-
mavTypeAdsb
→ const MavAutopilot
-
ADSB system
-
mavTypeAirship
→ const MavAutopilot
-
Airship, controlled
-
mavTypeAntennaTracker
→ const MavAutopilot
-
Ground installation
-
mavTypeBattery
→ const MavAutopilot
-
Battery
-
mavTypeCamera
→ const MavAutopilot
-
Camera
-
mavTypeChargingStation
→ const MavAutopilot
-
Charging station
-
mavTypeCoaxial
→ const MavAutopilot
-
Coaxial helicopter
-
mavTypeDecarotor
→ const MavAutopilot
-
Decarotor
-
mavTypeDodecarotor
→ const MavAutopilot
-
Dodecarotor
-
mavTypeFixedWing
→ const MavAutopilot
-
Fixed wing aircraft.
-
mavTypeFlappingWing
→ const MavAutopilot
-
Flapping wing
-
mavTypeFlarm
→ const MavAutopilot
-
FLARM collision avoidance system
-
mavTypeFreeBalloon
→ const MavAutopilot
-
Free balloon, uncontrolled
-
mavTypeGcs
→ const MavAutopilot
-
Operator control unit / ground control station
-
mavTypeGeneric
→ const MavAutopilot
-
Generic micro air vehicle
-
mavTypeGenericMultirotor
→ const MavAutopilot
-
Generic multirotor that does not fit into a specific type or whose type is unknown
-
mavTypeGimbal
→ const MavAutopilot
-
Gimbal
-
mavTypeGps
→ const MavAutopilot
-
GPS
-
mavTypeGroundRover
→ const MavAutopilot
-
Ground rover
-
mavTypeHelicopter
→ const MavAutopilot
-
Normal helicopter with tail rotor.
-
mavTypeHexarotor
→ const MavAutopilot
-
Hexarotor
-
mavTypeImu
→ const MavAutopilot
-
IMU
-
mavTypeKite
→ const MavAutopilot
-
Kite
-
mavTypeLog
→ const MavAutopilot
-
Log
-
mavTypeOctorotor
→ const MavAutopilot
-
Octorotor
-
mavTypeOdid
→ const MavAutopilot
-
Open Drone ID. See https://mavlink.io/en/services/opendroneid.html.
-
mavTypeOnboardController
→ const MavAutopilot
-
Onboard companion controller
-
mavTypeOsd
→ const MavAutopilot
-
OSD
-
mavTypeParachute
→ const MavAutopilot
-
Parachute
-
mavTypeParafoil
→ const MavAutopilot
-
Steerable, nonrigid airfoil
-
mavTypeQuadrotor
→ const MavAutopilot
-
Quadrotor
-
mavTypeRocket
→ const MavAutopilot
-
Rocket
-
mavTypeServo
→ const MavAutopilot
-
Servo
-
mavTypeSubmarine
→ const MavAutopilot
-
Submarine
-
mavTypeSurfaceBoat
→ const MavAutopilot
-
Surface vessel, boat, ship
-
mavTypeTricopter
→ const MavAutopilot
-
Tricopter
-
mavTypeVtolFixedrotor
→ const MavAutopilot
-
VTOL with separate fixed rotors for hover and cruise flight. Fuselage and wings stay (nominally) horizontal in all flight phases.
-
mavTypeVtolReserved5
→ const MavAutopilot
-
VTOL reserved 5
-
mavTypeVtolTailsitter
→ const MavAutopilot
-
Tailsitter VTOL. Fuselage and wings orientation changes depending on flight phase: vertical for hover, horizontal for cruise. Use more specific VTOL MAV_TYPE_VTOL_TAILSITTER_DUOROTOR or MAV_TYPE_VTOL_TAILSITTER_QUADROTOR if appropriate.
-
mavTypeVtolTailsitterDuorotor
→ const MavAutopilot
-
Two-rotor Tailsitter VTOL that additionally uses control surfaces in vertical operation. Note, value previously named MAV_TYPE_VTOL_DUOROTOR.
-
mavTypeVtolTailsitterQuadrotor
→ const MavAutopilot
-
Quad-rotor Tailsitter VTOL using a V-shaped quad config in vertical operation. Note: value previously named MAV_TYPE_VTOL_QUADROTOR.
-
mavTypeVtolTiltrotor
→ const MavAutopilot
-
Tiltrotor VTOL. Fuselage and wings stay (nominally) horizontal in all flight phases. It able to tilt (some) rotors to provide thrust in cruise flight.
-
mavTypeVtolTiltwing
→ const MavAutopilot
-
Tiltwing VTOL. Fuselage stays horizontal in all flight phases. The whole wing, along with any attached engine, can tilt between vertical and horizontal mode.
-
mavTypeWinch
→ const MavAutopilot
-
Winch
Typedefs
-
MavAutopilot
= int
-
Micro air vehicle / autopilot classes. This identifies the individual model.
-
MavComponent
= int
-
Component ids (values) for the different types and instances of onboard hardware/software that might make up a MAVLink system (autopilot, cameras, servos, GPS systems, avoidance systems etc.).
Components must use the appropriate ID in their source address when sending messages. Components can also use IDs to determine if they are the intended recipient of an incoming message. The MAV_COMP_ID_ALL value is used to indicate messages that must be processed by all components.
When creating new entries, components that can have multiple instances (e.g. cameras, servos etc.) should be allocated sequential values. An appropriate number of values should be left free after these components to allow the number of instances to be expanded.
-
MavModeFlag
= int
-
These flags encode the MAV mode.
-
MavModeFlagDecodePosition
= int
-
These values encode the bit positions of the decode position. These values can be used to read the value of a flag bit by combining the base_mode variable with AND with the flag position value. The result will be either 0 or 1, depending on if the flag is set or not.
-
MavState
= int
-
MAV_STATE
-
MavType
= int
-
MAVLINK component type reported in HEARTBEAT message. Flight controllers must report the type of the vehicle on which they are mounted (e.g. MAV_TYPE_OCTOROTOR). All other components must report a value appropriate for their type (e.g. a camera must use MAV_TYPE_CAMERA).