Battery2 class
2nd Battery status
BATTERY2
- Implemented types
Constructors
- Battery2({required uint16_t voltage, required int16_t currentBattery})
- Battery2.parse(ByteData data_)
-
factory
Properties
- currentBattery → AccelcalVehiclePos
-
Battery current, -1: autopilot does not measure the current.
final
- hashCode → AccelcalVehiclePos
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → AccelcalVehiclePos
-
no setteroverride
- mavlinkMessageId → AccelcalVehiclePos
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voltage → AccelcalVehiclePos
-
Voltage.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited