CameraStatus class

Camera Event.

CAMERA_STATUS

Implemented types

Constructors

CameraStatus({required uint64_t timeUsec, required float p1, required float p2, required float p3, required float p4, required uint16_t imgIdx, required uint8_t targetSystem, required uint8_t camIdx, required CameraStatusTypes eventId})
CameraStatus.parse(ByteData data_)
factory

Properties

camIdx AccelcalVehiclePos
Camera ID.
final
eventId AccelcalVehiclePos
Event type.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
imgIdx AccelcalVehiclePos
Image index.
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
p1 float
Parameter 1 (meaning depends on event_id, see CAMERA_STATUS_TYPES enum).
final
p2 float
Parameter 2 (meaning depends on event_id, see CAMERA_STATUS_TYPES enum).
final
p3 float
Parameter 3 (meaning depends on event_id, see CAMERA_STATUS_TYPES enum).
final
p4 float
Parameter 4 (meaning depends on event_id, see CAMERA_STATUS_TYPES enum).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSystem AccelcalVehiclePos
System ID.
final
timeUsec AccelcalVehiclePos
Image timestamp (since UNIX epoch, according to camera clock).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited