CompassmotStatus class

Status of compassmot calibration.

COMPASSMOT_STATUS

Implemented types

Constructors

CompassmotStatus({required float current, required float compensationx, required float compensationy, required float compensationz, required uint16_t throttle, required uint16_t interference})
CompassmotStatus.parse(ByteData data_)
factory

Properties

compensationx float
Motor Compensation X.
final
compensationy float
Motor Compensation Y.
final
compensationz float
Motor Compensation Z.
final
current float
Current.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
interference AccelcalVehiclePos
Interference.
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
throttle AccelcalVehiclePos
Throttle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited