DataTransmissionHandshake class

Handshake message to initiate, control and stop image streaming when using the Image Transmission Protocol: https://mavlink.io/en/services/image_transmission.html.

DATA_TRANSMISSION_HANDSHAKE

Implemented types

Constructors

DataTransmissionHandshake({required uint32_t size, required uint16_t width, required uint16_t height, required uint16_t packets, required MavlinkDataStreamType type, required uint8_t payload, required uint8_t jpgQuality})
DataTransmissionHandshake.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
height AccelcalVehiclePos
Height of a matrix or image.
final
jpgQuality AccelcalVehiclePos
JPEG quality. Values: 1-100.
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
packets AccelcalVehiclePos
Number of packets being sent (set on ACK only).
final
payload AccelcalVehiclePos
Payload size per packet (normally 253 byte, see DATA field size in message ENCAPSULATED_DATA) (set on ACK only).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size AccelcalVehiclePos
total data size (set on ACK only).
final
type AccelcalVehiclePos
Type of requested/acknowledged data.
final
width AccelcalVehiclePos
Width of a matrix or image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited