DeviceOpWrite class

Write registers for a device.

DEVICE_OP_WRITE

Implemented types

Constructors

DeviceOpWrite({required uint32_t requestId, required uint8_t targetSystem, required uint8_t targetComponent, required DeviceOpBustype bustype, required uint8_t bus, required uint8_t address, required List<int8_t> busname, required uint8_t regstart, required uint8_t count, required List<int8_t> data, required uint8_t bank})
DeviceOpWrite.parse(ByteData data_)
factory

Properties

address AccelcalVehiclePos
Bus address.
final
bank AccelcalVehiclePos
Bank number.
final
bus AccelcalVehiclePos
Bus number.
final
busname List<int8_t>
Name of device on bus (for SPI).
final
bustype AccelcalVehiclePos
The bus type.
final
count AccelcalVehiclePos
Count of registers to write.
final
data List<int8_t>
Write data.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
regstart AccelcalVehiclePos
First register to write.
final
requestId AccelcalVehiclePos
Request ID - copied to reply.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited