DeviceOpWriteReply class

Write registers reply.

DEVICE_OP_WRITE_REPLY

Implemented types

Constructors

DeviceOpWriteReply({required uint32_t requestId, required uint8_t result})
DeviceOpWriteReply.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
requestId AccelcalVehiclePos
Request ID - copied from request.
final
result AccelcalVehiclePos
0 for success, anything else is failure code.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited