FenceFetchPoint class

Request a current fence point from MAV.

FENCE_FETCH_POINT

Implemented types

Constructors

FenceFetchPoint({required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t idx})
FenceFetchPoint.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
idx AccelcalVehiclePos
Point index (first point is 1, 0 is for return point).
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited