HighLatency class

Message appropriate for high latency connections like Iridium

HIGH_LATENCY

Implemented types

Constructors

HighLatency({required uint32_t customMode, required int32_t latitude, required int32_t longitude, required int16_t roll, required int16_t pitch, required uint16_t heading, required int16_t headingSp, required int16_t altitudeAmsl, required int16_t altitudeSp, required uint16_t wpDistance, required MavModeFlag baseMode, required MavLandedState landedState, required int8_t throttle, required uint8_t airspeed, required uint8_t airspeedSp, required uint8_t groundspeed, required int8_t climbRate, required uint8_t gpsNsat, required GpsFixType gpsFixType, required uint8_t batteryRemaining, required int8_t temperature, required int8_t temperatureAir, required uint8_t failsafe, required uint8_t wpNum})
HighLatency.parse(ByteData data_)
factory

Properties

airspeed AccelcalVehiclePos
airspeed
final
airspeedSp AccelcalVehiclePos
airspeed setpoint
final
altitudeAmsl AccelcalVehiclePos
Altitude above mean sea level
final
altitudeSp AccelcalVehiclePos
Altitude setpoint relative to the home position
final
baseMode AccelcalVehiclePos
Bitmap of enabled system modes.
final
batteryRemaining AccelcalVehiclePos
Remaining battery (percentage)
final
climbRate AccelcalVehiclePos
climb rate
final
customMode AccelcalVehiclePos
A bitfield for use for autopilot-specific flags.
final
failsafe AccelcalVehiclePos
failsafe (each bit represents a failsafe where 0=ok, 1=failsafe active (bit0:RC, bit1:batt, bit2:GPS, bit3:GCS, bit4:fence)
final
gpsFixType AccelcalVehiclePos
GPS Fix type.
final
gpsNsat AccelcalVehiclePos
Number of satellites visible. If unknown, set to UINT8_MAX
final
groundspeed AccelcalVehiclePos
groundspeed
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
heading AccelcalVehiclePos
heading
final
headingSp AccelcalVehiclePos
heading setpoint
final
landedState AccelcalVehiclePos
The landed state. Is set to MAV_LANDED_STATE_UNDEFINED if landed state is unknown.
final
latitude AccelcalVehiclePos
Latitude
final
longitude AccelcalVehiclePos
Longitude
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
pitch AccelcalVehiclePos
pitch
final
roll AccelcalVehiclePos
roll
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature AccelcalVehiclePos
Autopilot temperature (degrees C)
final
temperatureAir AccelcalVehiclePos
Air temperature (degrees C) from airspeed sensor
final
throttle AccelcalVehiclePos
throttle (percentage)
final
wpDistance AccelcalVehiclePos
distance to target
final
wpNum AccelcalVehiclePos
current waypoint number
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited