LogRequestList class

Request a list of available logs. On some systems calling this may stop on-board logging until LOG_REQUEST_END is called. If there are no log files available this request shall be answered with one LOG_ENTRY message with id = 0 and num_logs = 0.

LOG_REQUEST_LIST

Implemented types

Constructors

LogRequestList({required uint16_t start, required uint16_t end, required uint8_t targetSystem, required uint8_t targetComponent})
LogRequestList.parse(ByteData data_)
factory

Properties

end AccelcalVehiclePos
Last log id (0xffff for last available)
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start AccelcalVehiclePos
First log id (0 for first available)
final
targetComponent AccelcalVehiclePos
Component ID
final
targetSystem AccelcalVehiclePos
System ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited