MagCalProgress class

Reports progress of compass calibration.

MAG_CAL_PROGRESS

Implemented types

Constructors

MagCalProgress({required float directionX, required float directionY, required float directionZ, required uint8_t compassId, required uint8_t calMask, required MagCalStatus calStatus, required uint8_t attempt, required uint8_t completionPct, required List<int8_t> completionMask})
MagCalProgress.parse(ByteData data_)
factory

Properties

attempt AccelcalVehiclePos
Attempt number.
final
calMask AccelcalVehiclePos
Bitmask of compasses being calibrated.
final
calStatus AccelcalVehiclePos
Calibration Status.
final
compassId AccelcalVehiclePos
Compass being calibrated.
final
completionMask List<int8_t>
Bitmask of sphere sections (see http://en.wikipedia.org/wiki/Geodesic_grid).
final
completionPct AccelcalVehiclePos
Completion percentage.
final
directionX float
Body frame direction vector for display.
final
directionY float
Body frame direction vector for display.
final
directionZ float
Body frame direction vector for display.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited