MountStatus class

Message with some status from autopilot to GCS about camera or antenna mount.

MOUNT_STATUS

Implemented types

Constructors

MountStatus({required int32_t pointingA, required int32_t pointingB, required int32_t pointingC, required uint8_t targetSystem, required uint8_t targetComponent, required MavMountMode mountMode})
MountStatus.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
mountMode AccelcalVehiclePos
Mount operating mode.
final
pointingA AccelcalVehiclePos
Pitch.
final
pointingB AccelcalVehiclePos
Roll.
final
pointingC AccelcalVehiclePos
Yaw.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited