ObstacleDistance3d class

Obstacle located as a 3D vector.

OBSTACLE_DISTANCE_3D

Implemented types

Constructors

ObstacleDistance3d({required uint32_t timeBootMs, required float x, required float y, required float z, required float minDistance, required float maxDistance, required uint16_t obstacleId, required MavDistanceSensor sensorType, required MavFrame frame})
ObstacleDistance3d.parse(ByteData data_)
factory

Properties

frame AccelcalVehiclePos
Coordinate frame of reference.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
maxDistance float
Maximum distance the sensor can measure.
final
minDistance float
Minimum distance the sensor can measure.
final
obstacleId AccelcalVehiclePos
Unique ID given to each obstacle so that its movement can be tracked. Use UINT16_MAX if object ID is unknown or cannot be determined.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorType AccelcalVehiclePos
Class id of the distance sensor type.
final
timeBootMs AccelcalVehiclePos
Timestamp (time since system boot).
final
x float
X position of the obstacle.
final
y float
Y position of the obstacle.
final
z float
Z position of the obstacle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited