Ping class

A ping message either requesting or responding to a ping. This allows to measure the system latencies, including serial port, radio modem and UDP connections. The ping microservice is documented at https://mavlink.io/en/services/ping.html

PING

Implemented types

Constructors

Ping({required uint64_t timeUsec, required uint32_t seq, required uint8_t targetSystem, required uint8_t targetComponent})
Ping.parse(ByteData data_)
factory

Properties

hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq AccelcalVehiclePos
PING sequence
final
targetComponent AccelcalVehiclePos
0: request ping from all receiving components. If greater than 0: message is a ping response and number is the component id of the requesting component.
final
targetSystem AccelcalVehiclePos
0: request ping from all receiving systems. If greater than 0: message is a ping response and number is the system id of the requesting system
final
timeUsec AccelcalVehiclePos
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited