Radio class

Status generated by radio.

RADIO

Implemented types

Constructors

Radio({required uint16_t rxerrors, required uint16_t fixed, required uint8_t rssi, required uint8_t remrssi, required uint8_t txbuf, required uint8_t noise, required uint8_t remnoise})
Radio.parse(ByteData data_)
factory

Properties

fixed AccelcalVehiclePos
Count of error corrected packets.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
noise AccelcalVehiclePos
Background noise level.
final
remnoise AccelcalVehiclePos
Remote background noise level.
final
remrssi AccelcalVehiclePos
Remote signal strength.
final
rssi AccelcalVehiclePos
Local signal strength.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rxerrors AccelcalVehiclePos
Receive errors.
final
txbuf AccelcalVehiclePos
How full the tx buffer is.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited