RallyPoint class

A rally point. Used to set a point when from GCS -> MAV. Also used to return a point from MAV -> GCS.

RALLY_POINT

Implemented types

Constructors

RallyPoint({required int32_t lat, required int32_t lng, required int16_t alt, required int16_t breakAlt, required uint16_t landDir, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t idx, required uint8_t count, required RallyFlags flags})
RallyPoint.parse(ByteData data_)
factory

Properties

alt AccelcalVehiclePos
Transit / loiter altitude relative to home.
final
breakAlt AccelcalVehiclePos
Break altitude relative to home.
final
count AccelcalVehiclePos
Total number of points (for sanity checking).
final
flags AccelcalVehiclePos
Configuration flags.
final
hashCode AccelcalVehiclePos
The hash code for this object.
no setterinherited
idx AccelcalVehiclePos
Point index (first point is 0).
final
landDir AccelcalVehiclePos
Heading to aim for when landing.
final
lat AccelcalVehiclePos
Latitude of point.
final
lng AccelcalVehiclePos
Longitude of point.
final
mavlinkCrcExtra AccelcalVehiclePos
no setteroverride
mavlinkMessageId AccelcalVehiclePos
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetComponent AccelcalVehiclePos
Component ID.
final
targetSystem AccelcalVehiclePos
System ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited