UalbertaSysStatus class

System status specific to ualberta uav

UALBERTA_SYS_STATUS

Implemented types

Constructors

UalbertaSysStatus({required uint8_t mode, required uint8_t navMode, required uint8_t pilot})
UalbertaSysStatus.parse(ByteData data_)
factory

Properties

hashCode ActuatorConfiguration
The hash code for this object.
no setterinherited
mavlinkCrcExtra ActuatorConfiguration
no setteroverride
mavlinkMessageId ActuatorConfiguration
no setteroverride
mode ActuatorConfiguration
System mode, see UALBERTA_AUTOPILOT_MODE ENUM
final
Navigation mode, see UALBERTA_NAV_MODE ENUM
final
pilot ActuatorConfiguration
Pilot mode, see UALBERTA_PILOT_MODE
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() ByteData
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited