CommandIntStamped class
Message encoding a command with parameters as scaled integers and additional metadata. Scaling depends on the actual command value.
COMMAND_INT_STAMPED
- Implemented types
Constructors
- CommandIntStamped({required uint64_t vehicleTimestamp, required uint32_t utcTime, required float param1, required float param2, required float param3, required float param4, required int32_t x, required int32_t y, required float z, required MavCmd command, required uint8_t targetSystem, required uint8_t targetComponent, required MavFrame frame, required uint8_t current, required uint8_t autocontinue})
- CommandIntStamped.parse(ByteData data_)
-
factory
Properties
- autocontinue → ActuatorConfiguration
-
autocontinue to next wp
final
- command → ActuatorConfiguration
-
The scheduled action for the mission item, as defined by MAV_CMD enum
final
- current → ActuatorConfiguration
-
false:0, true:1
final
- frame → ActuatorConfiguration
-
The coordinate system of the COMMAND, as defined by MAV_FRAME enum
final
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- param1 → float
-
PARAM1, see MAV_CMD enum
final
- param2 → float
-
PARAM2, see MAV_CMD enum
final
- param3 → float
-
PARAM3, see MAV_CMD enum
final
- param4 → float
-
PARAM4, see MAV_CMD enum
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetComponent → ActuatorConfiguration
-
Component ID
final
- targetSystem → ActuatorConfiguration
-
System ID
final
- utcTime → ActuatorConfiguration
-
UTC time, seconds elapsed since 01.01.1970
final
- vehicleTimestamp → ActuatorConfiguration
-
Microseconds elapsed since vehicle boot
final
- x → ActuatorConfiguration
-
PARAM5 / local: x position in meters * 1e4, global: latitude in degrees * 10^7
final
- y → ActuatorConfiguration
-
PARAM6 / local: y position in meters * 1e4, global: longitude in degrees * 10^7
final
- z → float
-
PARAM7 / z position: global: altitude in meters (MSL, WGS84, AGL or relative to home - depending on frame).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited