ComponentInformationBasic class
Basic component information data. Should be requested using MAV_CMD_REQUEST_MESSAGE on startup, or when required.
COMPONENT_INFORMATION_BASIC
- Implemented types
Constructors
-
ComponentInformationBasic({required MavProtocolCapability capabilities, required uint32_t timeBootMs, required uint32_t timeManufactureS, required List<
int8_t> vendorName, required List<int8_t> modelName, required List<int8_t> softwareVersion, required List<int8_t> hardwareVersion, required List<int8_t> serialNumber}) - ComponentInformationBasic.parse(ByteData data_)
-
factory
Properties
- capabilities → ActuatorConfiguration
-
Component capability flags
final
-
hardwareVersion
→ List<
int8_t> -
Hardware version. The recommended format is SEMVER: 'major.minor.patch' (any format may be used). The field must be zero terminated if it has a value. The field is optional and can be empty/all zeros.
final
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
-
modelName
→ List<
int8_t> -
Name of the component model. Needs to be zero terminated. The field is optional and can be empty/all zeros.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serialNumber
→ List<
int8_t> -
Hardware serial number. The field must be zero terminated if it has a value. The field is optional and can be empty/all zeros.
final
-
softwareVersion
→ List<
int8_t> -
Software version. The recommended format is SEMVER: 'major.minor.patch' (any format may be used). The field must be zero terminated if it has a value. The field is optional and can be empty/all zeros.
final
- timeBootMs → ActuatorConfiguration
-
Timestamp (time since system boot).
final
- timeManufactureS → ActuatorConfiguration
-
Date of manufacture as a UNIX Epoch time (since 1.1.1970) in seconds.
final
-
vendorName
→ List<
int8_t> -
Name of the component vendor. Needs to be zero terminated. The field is optional and can be empty/all zeros.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited