GimbalManagerStatus class
Current status about a high level gimbal manager. This message should be broadcast at a low regular rate (e.g. 5Hz).
GIMBAL_MANAGER_STATUS
- Implemented types
Constructors
- GimbalManagerStatus({required uint32_t timeBootMs, required GimbalManagerFlags flags, required uint8_t gimbalDeviceId, required uint8_t primaryControlSysid, required uint8_t primaryControlCompid, required uint8_t secondaryControlSysid, required uint8_t secondaryControlCompid})
- GimbalManagerStatus.parse(ByteData data_)
-
factory
Properties
- flags → ActuatorConfiguration
-
High level gimbal manager flags currently applied.
final
- gimbalDeviceId → ActuatorConfiguration
-
Gimbal device ID that this gimbal manager is responsible for. Component ID of gimbal device (or 1-6 for non-MAVLink gimbal).
final
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- primaryControlCompid → ActuatorConfiguration
-
Component ID of MAVLink component with primary control, 0 for none.
final
- primaryControlSysid → ActuatorConfiguration
-
System ID of MAVLink component with primary control, 0 for none.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryControlCompid → ActuatorConfiguration
-
Component ID of MAVLink component with secondary control, 0 for none.
final
- secondaryControlSysid → ActuatorConfiguration
-
System ID of MAVLink component with secondary control, 0 for none.
final
- timeBootMs → ActuatorConfiguration
-
Timestamp (time since system boot).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited