HygrometerSensor class
Temperature and humidity from hygrometer.
HYGROMETER_SENSOR
- Implemented types
Constructors
- HygrometerSensor({required int16_t temperature, required uint16_t humidity, required uint8_t id})
- HygrometerSensor.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- humidity → ActuatorConfiguration
-
Humidity
final
- id → ActuatorConfiguration
-
Hygrometer ID
final
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperature → ActuatorConfiguration
-
Temperature
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited