NamedValueInt class
Send a key-value pair as integer. The use of this message is discouraged for normal packets, but a quite efficient way for testing new messages and getting experimental debug output.
NAMED_VALUE_INT
- Implemented types
Constructors
-
NamedValueInt({required uint32_t timeBootMs, required int32_t value, required List<
int8_t> name}) - NamedValueInt.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
-
name
→ List<
int8_t> -
Name of the debug variable
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeBootMs → ActuatorConfiguration
-
Timestamp (time since system boot).
final
- value → ActuatorConfiguration
-
Signed integer value
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited