cellularStatusFlagRegistered top-level constant

CellularStatusFlag const cellularStatusFlagRegistered

Modem is registered with a network provider, and data connections and messaging may be available for use

CELLULAR_STATUS_FLAG_REGISTERED

Implementation

const CellularStatusFlag cellularStatusFlagRegistered = 9;