SerialUdbExtraF13 class
Backwards compatible version of SERIAL_UDB_EXTRA F13: format
SERIAL_UDB_EXTRA_F13
- Implemented types
Constructors
- SerialUdbExtraF13({required int32_t sueLatOrigin, required int32_t sueLonOrigin, required int32_t sueAltOrigin, required int16_t sueWeekNo})
- SerialUdbExtraF13.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sueAltOrigin → ActuatorConfiguration
-
Serial UDB Extra MP Origin Altitude Above Sea Level
final
- sueLatOrigin → ActuatorConfiguration
-
Serial UDB Extra MP Origin Latitude
final
- sueLonOrigin → ActuatorConfiguration
-
Serial UDB Extra MP Origin Longitude
final
- sueWeekNo → ActuatorConfiguration
-
Serial UDB Extra GPS Week Number
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited