SerialUdbExtraF19 class
Backwards compatible version of SERIAL_UDB_EXTRA F19 format
SERIAL_UDB_EXTRA_F19
- Implemented types
Constructors
- SerialUdbExtraF19({required uint8_t sueAileronOutputChannel, required uint8_t sueAileronReversed, required uint8_t sueElevatorOutputChannel, required uint8_t sueElevatorReversed, required uint8_t sueThrottleOutputChannel, required uint8_t sueThrottleReversed, required uint8_t sueRudderOutputChannel, required uint8_t sueRudderReversed})
- SerialUdbExtraF19.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sueAileronOutputChannel → ActuatorConfiguration
-
SUE aileron output channel
final
- sueAileronReversed → ActuatorConfiguration
-
SUE aileron reversed
final
- sueElevatorOutputChannel → ActuatorConfiguration
-
SUE elevator output channel
final
- sueElevatorReversed → ActuatorConfiguration
-
SUE elevator reversed
final
- sueRudderOutputChannel → ActuatorConfiguration
-
SUE rudder output channel
final
- sueRudderReversed → ActuatorConfiguration
-
SUE rudder reversed
final
- sueThrottleOutputChannel → ActuatorConfiguration
-
SUE throttle output channel
final
- sueThrottleReversed → ActuatorConfiguration
-
SUE throttle reversed
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited