SerialUdbExtraF21 class
Backwards compatible version of SERIAL_UDB_EXTRA F21 format
SERIAL_UDB_EXTRA_F21
- Implemented types
Constructors
- SerialUdbExtraF21({required int16_t sueAccelXOffset, required int16_t sueAccelYOffset, required int16_t sueAccelZOffset, required int16_t sueGyroXOffset, required int16_t sueGyroYOffset, required int16_t sueGyroZOffset})
- SerialUdbExtraF21.parse(ByteData data_)
-
factory
Properties
- hashCode → ActuatorConfiguration
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → ActuatorConfiguration
-
no setteroverride
- mavlinkMessageId → ActuatorConfiguration
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sueAccelXOffset → ActuatorConfiguration
-
SUE X accelerometer offset
final
- sueAccelYOffset → ActuatorConfiguration
-
SUE Y accelerometer offset
final
- sueAccelZOffset → ActuatorConfiguration
-
SUE Z accelerometer offset
final
- sueGyroXOffset → ActuatorConfiguration
-
SUE X gyro offset
final
- sueGyroYOffset → ActuatorConfiguration
-
SUE Y gyro offset
final
- sueGyroZOffset → ActuatorConfiguration
-
SUE Z gyro offset
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited