MountConfigure class
Message to configure a camera mount, directional antenna, etc.
MOUNT_CONFIGURE
- Implemented types
Constructors
- MountConfigure({required uint8_t targetSystem, required uint8_t targetComponent, required MavMountMode mountMode, required uint8_t stabRoll, required uint8_t stabPitch, required uint8_t stabYaw})
- MountConfigure.parse(ByteData data_)
-
factory
Properties
- hashCode → AccelcalVehiclePos
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → AccelcalVehiclePos
-
no setteroverride
- mavlinkMessageId → AccelcalVehiclePos
-
no setteroverride
- mountMode → AccelcalVehiclePos
-
Mount operating mode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stabPitch → AccelcalVehiclePos
-
(1 = yes, 0 = no).
final
- stabRoll → AccelcalVehiclePos
-
(1 = yes, 0 = no).
final
- stabYaw → AccelcalVehiclePos
-
(1 = yes, 0 = no).
final
- targetComponent → AccelcalVehiclePos
-
Component ID.
final
- targetSystem → AccelcalVehiclePos
-
System ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited