OsdParamConfigReply class
Configure OSD parameter reply.
OSD_PARAM_CONFIG_REPLY
- Implemented types
Constructors
- OsdParamConfigReply({required uint32_t requestId, required OsdParamConfigError result})
- OsdParamConfigReply.parse(ByteData data_)
-
factory
Properties
- hashCode → AccelcalVehiclePos
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → AccelcalVehiclePos
-
no setteroverride
- mavlinkMessageId → AccelcalVehiclePos
-
no setteroverride
- requestId → AccelcalVehiclePos
-
Request ID - copied from request.
final
- result → AccelcalVehiclePos
-
Config error type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited