OsdParamShowConfig class
Read a configured an OSD parameter slot.
OSD_PARAM_SHOW_CONFIG
- Implemented types
Constructors
- OsdParamShowConfig({required uint32_t requestId, required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t osdScreen, required uint8_t osdIndex})
- OsdParamShowConfig.parse(ByteData data_)
-
factory
Properties
- hashCode → AccelcalVehiclePos
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → AccelcalVehiclePos
-
no setteroverride
- mavlinkMessageId → AccelcalVehiclePos
-
no setteroverride
- osdIndex → AccelcalVehiclePos
-
OSD parameter display index.
final
- osdScreen → AccelcalVehiclePos
-
OSD parameter screen index.
final
- requestId → AccelcalVehiclePos
-
Request ID - copied to reply.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetComponent → AccelcalVehiclePos
-
Component ID.
final
- targetSystem → AccelcalVehiclePos
-
System ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited