ParamValueArray class
Parameter multi param value container.
PARAM_VALUE_ARRAY
- Implemented types
Constructors
-
ParamValueArray({required uint16_t paramCount, required uint16_t paramIndexFirst, required uint16_t flags, required uint8_t paramArrayLen, required List<
int8_t> packetBuf}) - ParamValueArray.parse(ByteData data_)
-
factory
Properties
- flags → AccelcalVehiclePos
-
Flags.
final
- hashCode → AccelcalVehiclePos
-
The hash code for this object.
no setterinherited
- mavlinkCrcExtra → AccelcalVehiclePos
-
no setteroverride
- mavlinkMessageId → AccelcalVehiclePos
-
no setteroverride
-
packetBuf
→ List<
int8_t> -
Parameters buffer. Contains a series of variable length parameter blocks, one per parameter, with format as specifed elsewhere.
final
- paramArrayLen → AccelcalVehiclePos
-
Number of onboard parameters in this array.
final
- paramCount → AccelcalVehiclePos
-
Total number of onboard parameters.
final
- paramIndexFirst → AccelcalVehiclePos
-
Index of the first onboard parameter in this array.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited