RallyFetchPoint class
Request a current rally point from MAV. MAV should respond with a RALLY_POINT message. MAV should not respond if the request is invalid.
RALLY_FETCH_POINT
- Implemented types
Constructors
- RallyFetchPoint({required uint8_t targetSystem, required uint8_t targetComponent, required uint8_t idx})
- RallyFetchPoint.parse(ByteData data_)
-
factory
Properties
- hashCode → AccelcalVehiclePos
-
The hash code for this object.
no setterinherited
- idx → AccelcalVehiclePos
-
Point index (first point is 0).
final
- mavlinkCrcExtra → AccelcalVehiclePos
-
no setteroverride
- mavlinkMessageId → AccelcalVehiclePos
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetComponent → AccelcalVehiclePos
-
Component ID.
final
- targetSystem → AccelcalVehiclePos
-
System ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → ByteData -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited